@@ -194,7 +194,7 @@ int export_all_bands_adif(void){
     
     dbg("export_all_bands_adif()\n");
     
-    filename = g_strdup_printf("%s/%s_%s.adif",
+    filename = g_strdup_printf("%s/%s_%s.adi",
                     ctest->directory,
                     ctest->cdate,
                     z_get_raw_call(callbuf,ctest->pcall));
