@@ -230,6 +230,7 @@ static void display_menu(struct menu *menu)
 
 void menu_func(struct window *win, struct event *ev, int fwd)
 {
+    //dbg("menu_func");
     int s = 0;
     struct menu *menu = (struct menu*)win->data;
     struct window *w1;
@@ -423,6 +424,7 @@ static void select_mainmenu(struct mainmenu *menu)
 
 void mainmenu_func(struct window *win, struct event *ev, int fwd)
 {
+    //dbg("mainmenu_func");
     int s = 0;
     struct mainmenu *menu = (struct mainmenu *)win->data;
     menu->win = win;
@@ -719,7 +721,7 @@ void dialog_func(struct window *win, struct event *ev, int fwd)
     struct dialog_item_data *di;
 
     dlg->win = win;
-/*    dbg("dialog_func(%p,[%d,%d,%d,%d],%d)\n",win,ev->ev,ev->x,ev->y,ev->b,fwd);*/
+    //dbg("dialog_func(%p,[%d,%d,%d,%d],%d)\n",win,ev->ev,ev->x,ev->y,ev->b,fwd);
     /* Use nonstandard event handlers */
     if (dlg->dlg->handle_event && ((dlg->dlg->handle_event)(dlg, ev) == EVENT_PROCESSED) ) {
         return;
@@ -752,18 +754,19 @@ void dialog_func(struct window *win, struct event *ev, int fwd)
                 }
                 init_list(di->history);
                 if (di->item->type == D_FIELD || di->item->type == D_FIELD_PASS) {
-                    if (di->item->history) {
+                    /*if (di->item->history) {
                         struct history_item *j;
-                        /*int l = di->item->dlen;*/
+                        //int l = di->item->dlen;
                         foreach(j, di->item->history->items) {
                             struct history_item *hi;
                             if (!(hi = g_malloc(sizeof(struct history_item) + strlen(j->d) + 1))) continue;
                             strcpy(hi->d, j->d);
-                            add_to_list(di->history, hi);
+                            struct list_head *h = &di->history;
+                            add_to_list(*h, hi);
                         }
-                    }
+                    } */
                     di->cpos = strlen(di->cdata);
-                }
+                } 
             }
             dlg->selected = 0;
 			while (dlg->dlg->items[dlg->selected].type == D_TEXT) dlg->selected ++;  // no focus for D_TEXT
@@ -1496,7 +1499,7 @@ void msg_box(struct memory_list *ml, char *title,
 
 void add_to_history(struct history *h, char *t)
 {
-    struct history_item *hi, *hs;
+/*    struct history_item *hi, *hs;
     int l;
     if (!h || !t || !*t) return;
     l = strlen(t) + 1;
@@ -1509,7 +1512,7 @@ void add_to_history(struct history *h, char *t)
         g_free(hd);
         h->n--;
     }
-    add_to_list(h->items, hi);
+    add_to_list(*h, hi);
     h->n++;
     while (h->n > MAX_HISTORY_ITEMS) {
         struct history_item *hd = h->items.prev;
@@ -1521,7 +1524,7 @@ void add_to_history(struct history *h, char *t)
         del_from_list(hd);
         g_free(hd);
         h->n--;
-    }
+    }*/
 }
 
 static int input_field_cancel(struct dialog_data *dlg, struct dialog_item_data *di)
