@@ -65,7 +65,7 @@ int export_all_bands_cbr(void){
     char t[256];
     GString *gs;
     char *categoryband = NULL;
-    
+	int complete;
 
     if (!ctest) return -1;
     
@@ -136,6 +136,7 @@ int export_all_bands_cbr(void){
     fprintf(f, "CATEGORY-TRANSMITTER: ONE\r\n");
     fprintf(f, "LOCATION: Write here\r\n");
     fprintf(f, "CLAIMED-SCORE: %d\r\n", ctest->allb_ntotal); 
+	fprintf(f, "SPECIFIC: %s\r\n", ctest->pexch);
     fprintf(f, "CLUB: %s\r\n", ctest->pclub);
     fprintf(f, "NAME: %s\r\n", ctest->rname);
     fprintf(f, "ADDRESS: %s %s\r\n", ctest->radr1, ctest->radr2);
@@ -144,6 +145,8 @@ int export_all_bands_cbr(void){
     fprintf(f, "ADDRESS-POSTALCODE: %s\r\n", ctest->rpoco);
     fprintf(f, "SOAPBOX: %s\r\n", gs->str); 
 
+	complete = (ctest->excused > 0) && (ctest->wwlused > 0) && (ctest->qsoused > 0); // UKSMG
+
     for (i=0; i<ctest->allqsos->len; i++){
         struct qso *q = (struct qso *)z_ptr_array_index(ctest->allqsos, i);
         char *c, *d = NULL;
@@ -170,7 +173,7 @@ int export_all_bands_cbr(void){
         if (!d) d = "      "; 
         
 
-        fprintf(f, "QSO: ");
+        fprintf(f, "%sQSO: ", q->error ? "X-" : "");
         if (q->qrg > 0 && q->qrg < 100000000){
             fprintf(f, "%5d ", (int)(q->qrg / 1000.0));
         }else{
@@ -192,13 +195,32 @@ int export_all_bands_cbr(void){
         fprintf(f, "%s ", padr(s, t, 10));
         
         fprintf(f, "%s ", padr(s, q->time_str, 4));
-        fprintf(f, "%s ", padr(s, ctest->pcall,13));
-        fprintf(f, "%s ", padr(s, q->rsts,3));
-        fprintf(f, "%s ", padr(s, c, 6));
+        fprintf(f, "%s ", padr(s, ctest->pcall, 13));
+		fprintf(f, "%s ", padr(s, q->rsts, 3));
+		if (complete)
+		{
+			fprintf(f, "%s ", padr(s, q->qsonrs, 4));
+			fprintf(f, "%s ", padr(s, ctest->pwwlo, 6));
+			g_strlcpy(t, ctest->pexch, sizeof(t));
+			g_strstrip(t);
+			fprintf(f, "%s ", padr(s, t, strlen(ctest->pexch)));
+		}else{
+			fprintf(f, "%s ", padr(s, c, 6));
+		}
 
         fprintf(f, "%s ", padr(s, q->callsign,13));
         fprintf(f, "%s ", padr(s, q->rstr,3));
-        fprintf(f, "%s ", padr(s, d, 6));
+		if (complete)
+		{
+			fprintf(f, "%s ", padr(s, q->qsonrr, 4));
+			fprintf(f, "%s ", padr(s, q->locator, 6));
+			g_strlcpy(t, q->exc, sizeof(t));
+			g_strstrip(t);
+			fprintf(f, "%s ", padr(s, t, ctest->exclen));
+		}
+		else{
+			fprintf(f, "%s ", padr(s, d, 6));
+		}
         fprintf(f, "\r\n");
 
     }
