@@ -95,6 +95,19 @@ struct cwdaemon *init_cwdaemon(void){
             cwda->ssbway  = ttys_ssbway;
             cwda->back    = cwdaemon_back;
             break;
+
+		case CWD_TTYS_SINGLE:
+			cwda->init = ttys_init;
+			cwda->free = ttys_free;
+			cwda->reset = ttys_reset;
+			cwda->text = cwdaemon_text;
+			cwda->sspeed = cwdaemon_speed;
+			cwda->sweight = cwdaemon_weight;
+			cwda->cw = ttys_cw_single;
+			cwda->ptt = ttys_ptt_single;
+			cwda->ssbway = ttys_ssbway;
+			cwda->back = cwdaemon_back;
+			break;
 		case CWD_DAVAC4:
 #ifdef Z_HAVE_LIBFTDI
             cwda->init    = davac4_init;
@@ -267,9 +280,10 @@ static void cwenqueue(struct cwdaemon *cwda){
             return;
         }
         g_string_erase(cwda->code, 0, 1);
-        if (ch != '\x09') g_string_append_c(cwda->played, ch);
+        if (ch != '\x09' && ch != '^') g_string_append_c(cwda->played, ch);
         switch(ch){
             case '\x09': strcpy(s, "\x09"); break;
+            case '^': strcpy(s, "^"); break;
             case ' ': strcpy(s, " ");      break;
             case 'A': strcpy(s, ".-");     break;
             case 'B': strcpy(s, "-...");   break;          
@@ -393,6 +407,16 @@ static void cwenqueue(struct cwdaemon *cwda){
             tv.tv_usec+=1000*cfg->cwda_leadin;
             while (tv.tv_usec>=1000000) {tv.tv_usec-=1000000;tv.tv_sec++; }
             i++;
+        }
+		if (*c=='^'){
+            cwqueue[i].tv.tv_sec=tv.tv_sec;       
+            cwqueue[i].tv.tv_usec=tv.tv_usec;       
+            cwqueue[i].on=0;
+            cwqueue[i].last=0;
+            cwqueue[i].ch=*c;
+            tv.tv_usec+=1000*cfg->cwda_tail;
+            while (tv.tv_usec>=1000000) {tv.tv_usec-=1000000;tv.tv_sec++; }
+            i++;
         }
     }
     cwqueue[i].tv.tv_sec=tv.tv_sec;
@@ -501,6 +525,8 @@ gpointer cwdaemon_thread_func(gpointer data){
                         break;
                 }
             }
+            //if (!cwda->hold_ptt) g_string_append_c(cwda->code, '^');
+
             if (qi<0 && *cwda->code->str){
                 //dbg("cwenqueue 1 tune=%d qi=%d\n", cwda->tune, qi);
                 cwenqueue(cwda);
@@ -677,6 +703,7 @@ void cwdaemon_ptt(struct cwdaemon *cwda, int ptt, int hold_ptt){
 		cwda->ptt(cwda, ptt);        
 		if (cwda->hold_ptt) g_string_append_c(cwda->code, '\x09');
 	}
+
 #ifdef HAVE_HAMLIB
 	trigs_set_ptt(gtrigs, ptt);
 #endif
