@@ -17,7 +17,7 @@
 
 struct cq;
 
-enum cwtype { CWD_NONE, CWD_PARPORT, CWD_TTYS, CWD_DAVAC4, CWD_CWD, CWD_WINKEY, CWD_WINKEY4x, CWD_WINKEYTCP};
+enum cwtype { CWD_NONE, CWD_PARPORT, CWD_TTYS, CWD_DAVAC4, CWD_CWD, CWD_WINKEY, CWD_WINKEY4x, CWD_WINKEYTCP, CWD_TTYS_SINGLE};
 
 struct cwdaemon {
 	int (*init)    (struct cwdaemon *);
