@@ -31,7 +31,7 @@ struct cw *init_cw(void){
     time_t now;
     struct tm tm;
 
-	progress(VTEXT(T_INIT_CWDB));		
+    progress(VTEXT(T_INIT_CWDB));       
     cw = g_new0(struct cw, 1);
     
     cw->cw = z_hash_table_new(g_str_hash, g_str_equal);
@@ -74,7 +74,7 @@ static gboolean free_wc_item(gpointer key, gpointer value, gpointer user_data){
 }
 
 void free_cw(struct cw *cw){
-	progress(VTEXT(T_TERM_CWDB));		
+    progress(VTEXT(T_TERM_CWDB));       
 
     g_hash_table_foreach_remove(cw->wc, free_wc_item, NULL);
     g_hash_table_destroy(cw->wc);
@@ -101,7 +101,7 @@ void load_one_cw(struct cw *cw, gchar *s){
     z_str_uc(s);
     call = strtok_r(s, CW_DELIM, &token_ptr);
     if (!call) return;
-	z_strip_from(call, '-');  // before 3.15 in db can be calls with SSID from KST
+    z_strip_from(call, '-');  // before 3.15 in db can be calls with SSID from KST
 
     wwl = strtok_r(NULL, CW_DELIM, &token_ptr);
     if (!wwl) return;
@@ -136,14 +136,14 @@ int load_cw_from_file(struct cw *cw, gchar *filename){
 
 int load_cw_from_mem(struct cw *cw, const char *file, size_t len){
     GString *gs; 
-	long int pos;
+    long int pos;
     
     gs = g_string_sized_new(100);
     
     pos=0;
     while(1){
         if (!zfile_mgets(gs, file, &pos, len, 1)) break;
-		load_one_cw(cw, gs->str);
+        load_one_cw(cw, gs->str);
     }
     g_string_free(gs, 1);
     return 0;
@@ -152,18 +152,18 @@ int load_cw_from_mem(struct cw *cw, const char *file, size_t len){
 
 void read_cw_files(struct cw *cw){
     gchar *s;
-	int ret = 0;
+    int ret = 0;
     
-	progress(VTEXT(T_LOADING_CWDB));		
+    progress(VTEXT(T_LOADING_CWDB));        
 
 /*#ifdef UNIX
     ret |= load_cw_from_file(cw, "/etc/tucnakcw");
 #endif*/
     s = g_strconcat(tucnak_dir, "/tucnakcw", NULL); 
-	z_wokna(s);
+    z_wokna(s);
     ret |= load_cw_from_file(cw, s);
-	if (ret) load_cw_from_mem(cw, txt_tucnakcw, sizeof(txt_tucnakcw));
-	cw->dirty = 0;
+    if (ret) load_cw_from_mem(cw, txt_tucnakcw, sizeof(txt_tucnakcw));
+    cw->dirty = 0;
     g_free(s);
 }
 
@@ -173,7 +173,7 @@ static void save_one_cw(gpointer key, gpointer value, gpointer user_data){
     struct cw_item *cwi;
     gchar qrv_str[33], *c;
     int i;
-	char s[4096];
+    char s[4096];
 
     gs   = (GString *) user_data;
     call = (gchar *) key;
@@ -187,17 +187,17 @@ static void save_one_cw(gpointer key, gpointer value, gpointer user_data){
     *c='\0';
 
     if (cwi->wwl0){ 
-		sprintf(s, "%-14s %-6s %08d %s\n", call, cwi->wwl0, cwi->stamp0, qrv_str);
-		g_string_append(gs, s);
-		// g_string_sprintfa is incredibely slow under msvc
+        sprintf(s, "%-14s %-6s %08d %s\n", call, cwi->wwl0, cwi->stamp0, qrv_str);
+        g_string_append(gs, s);
+        // g_string_sprintfa is incredibely slow under msvc
         //g_string_sprintfa(gs, "%-14s %-6s %08d %s\n", call, cwi->wwl0, cwi->stamp0, qrv_str);
-	}
+    }
     
     if (cwi->wwl1){
-		sprintf(s, "%-14s %-6s %08d %s\n", call, cwi->wwl1, cwi->stamp1, qrv_str);
-		g_string_append(gs, s);
+        sprintf(s, "%-14s %-6s %08d %s\n", call, cwi->wwl1, cwi->stamp1, qrv_str);
+        g_string_append(gs, s);
         //g_string_sprintfa(gs, "%-14s %-6s %08d %s\n", call, cwi->wwl1, cwi->stamp1, qrv_str);
-	}
+    }
     
 }
 
@@ -225,21 +225,21 @@ int save_cw_into_file(struct cw *cw, gchar *filename){
 }
 
 int save_cw(struct cw *cw, int verbose){
-	char *s;
-	int ret;
+    char *s;
+    int ret;
 
-	if (!cw->dirty) return 0;
-	s = g_strconcat(tucnak_dir, "/tucnakcw", NULL);
-	z_wokna(s);
+    if (!cw->dirty) return 0;
+    s = g_strconcat(tucnak_dir, "/tucnakcw", NULL);
+    z_wokna(s);
     ret=save_cw_into_file(cw, s);        
     if (ret){
         errbox(VTEXT(T_CANT_WRITE), ret);
     }else{
-		if (verbose) log_addf(VTEXT(T_SAVED_S), s);
-		cw->dirty = 0;
+        if (verbose) log_addf(VTEXT(T_SAVED_S), s);
+        cw->dirty = 0;
     }
     g_free(s);
-	return ret;
+    return ret;
 }
 
 
@@ -249,7 +249,7 @@ static void format_one_cw(gpointer key, gpointer value, gpointer user_data){
     struct cw_item *cwi;
     gchar qrv_str[33], *c;
     int i;
-	char s[4096];
+    char s[4096];
 
     gs   = (GString *) user_data;
     call = (gchar *) key;
@@ -263,17 +263,17 @@ static void format_one_cw(gpointer key, gpointer value, gpointer user_data){
     *c='\0';
 
     if (cwi->wwl0){ 
-		sprintf(s, "%s %s %d %s;", call, cwi->wwl0, cwi->stamp0, qrv_str);
-		g_string_append(gs, s);
-		// g_string_sprintfa is incredibely slow under msvc
+        sprintf(s, "%s %s %d %s;", call, cwi->wwl0, cwi->stamp0, qrv_str);
+        g_string_append(gs, s);
+        // g_string_sprintfa is incredibely slow under msvc
         //g_string_sprintfa(gs, "%-14s %-6s %08d %s\n", call, cwi->wwl0, cwi->stamp0, qrv_str);
-	}
+    }
     
     if (cwi->wwl1){
-		sprintf(s, "%4s %s %d %s;", call, cwi->wwl1, cwi->stamp1, qrv_str);
-		g_string_append(gs, s);
+        sprintf(s, "%4s %s %d %s;", call, cwi->wwl1, cwi->stamp1, qrv_str);
+        g_string_append(gs, s);
         //g_string_sprintfa(gs, "%-14s %-6s %08d %s\n", call, cwi->wwl1, cwi->stamp1, qrv_str);
-	}
+    }
     
 }
 
@@ -310,13 +310,13 @@ void add_cw(struct cw *cw, gchar *call, gchar *wwl, gint stamp, gchar *qrv_str){
         if (cwi->wwl1) g_free(cwi->wwl1);
         cwi->wwl1   = g_strdup(wwl);
         cwi->stamp1 = stamp;
-		cw->dirty = 1;
+        cw->dirty = 1;
         return;
     }
 
     if (cwi->wwl0 && strcasecmp(cwi->wwl0, wwl)==0) {
         cwi->stamp0 = stamp;
-		cw->dirty = 1;
+        cw->dirty = 1;
         return;
     }
 
@@ -326,7 +326,7 @@ void add_cw(struct cw *cw, gchar *call, gchar *wwl, gint stamp, gchar *qrv_str){
     
     cwi->wwl0   = g_strdup(wwl);
     cwi->stamp0 = stamp;
-	cw->dirty = 1;
+    cw->dirty = 1;
 }
 
 
@@ -489,7 +489,7 @@ int cmp_cw_qs(gchar *call, struct cw_item *cwi, GPtrArray *result){
     int qrvfilter;
     char degree[2];
 
-#ifdef Z_HAVE_SDL    
+#if defined(Z_HAVE_SDL) && !defined(Z_ANDROID)     
     if (sdl) 
         strcpy(degree, "\xb0");
     else
@@ -564,7 +564,7 @@ void get_cw_qs(gchar *str){
         zg_free0(gses->qs_str);
         gses->qs_str=g_strdup(str);
         gses->qs_max_matches = term->y - QSONR_HEIGHT - 4 - cfg->loglines - 1;
-		if (ctest && !ctest->oldcontest) gses->qs_max_matches -= ctest->spypeers->len;
+        if (ctest && !ctest->oldcontest) gses->qs_max_matches -= ctest->spypeers->len;
         if (ctest && ctest->bands->len==1) gses->qs_max_matches*=2;
         if (!ctest) gses->qs_max_matches*=3;
         qs_thread_create();
@@ -576,7 +576,7 @@ static gpointer qs_thread_func(gpointer data){
     ZHashNode *node;
     gint i;
 
-	zg_thread_set_name("Tucnak quicksearch");
+    zg_thread_set_name("Tucnak quicksearch");
 
     result=g_ptr_array_new();
     
@@ -603,9 +603,9 @@ x:;
     
     //sprintf(s, "CWQS\n");
     //ret = write(tpipe->threadpipe_write, s, strlen(s));
-	zselect_msg_send(zsel, "CWQS");
+    zselect_msg_send(zsel, "CWQS");
 
-	return NULL;
+    return NULL;
 }
 
 void qs_thread_create(void){
@@ -697,7 +697,7 @@ int get_susp_ambiguous_call(struct cw *cw, struct band *band, char *call, char *
 
     for (i = 0; i < cw->cw->size; i++){
         for (node = cw->cw->nodes[i]; node; node = node->next){
-			int factor;
+            int factor;
             cwi  = (struct cw_item *) node->value;
             
             if ((cwi->wwl0 && strcmp(cwi->wwl0, wwl)==0 && cwi->stamp0 > cw->minstamp) ||
@@ -725,7 +725,7 @@ int cwdb_call_info(GString *gs, gchar *call, gchar *stroke, GHashTable *wwls){
     struct cw_item *cwi;
     char c[40], *myqth;
     int i;
-	double qrb, qtf;
+    double qrb, qtf;
     char degree[2];
  
     strcpy(c, call);
@@ -733,25 +733,25 @@ int cwdb_call_info(GString *gs, gchar *call, gchar *stroke, GHashTable *wwls){
     cwi = (struct cw_item *)z_hash_table_lookup(cw->cw, c);
     if (!cwi) return 0;
 
-#ifdef Z_HAVE_SDL    
+#if defined(Z_HAVE_SDL) && !defined(Z_ANDROID)     
     if (sdl) 
         strcpy(degree, "\xb0");
     else
 #endif
         strcpy(degree, "");
 
-	myqth = ctest ? ctest->pwwlo : cfg->pwwlo;
-	 /* wwl0 should be always defined */
+    myqth = ctest ? ctest->pwwlo : cfg->pwwlo;
+     /* wwl0 should be always defined */
     if (cwi->wwl0) {
-		qrbqtf(myqth, cwi->wwl0, &qrb, &qtf, NULL, 0);
-		g_string_sprintfa(gs, "C_W: %-10s %s %6dkm %3d%s  %d\n", c, cwi->wwl0, (int)qrb, (int)qtf, degree, cwi->stamp0);
-		if (wwls && g_hash_table_lookup(wwls, cwi->wwl0) == NULL) g_hash_table_insert(wwls, cwi->wwl0, NULL);
-	}
+        qrbqtf(myqth, cwi->wwl0, &qrb, &qtf, NULL, 0);
+        g_string_sprintfa(gs, "C_W: %-10s %s %6dkm %3d%s  %d\n", c, cwi->wwl0, (int)qrb, (int)qtf, degree, cwi->stamp0);
+        if (wwls && g_hash_table_lookup(wwls, cwi->wwl0) == NULL) g_hash_table_insert(wwls, cwi->wwl0, NULL);
+    }
     if (cwi->wwl1) {
-		qrbqtf(myqth, cwi->wwl1, &qrb, &qtf, NULL, 0);
-		g_string_sprintfa(gs, "C_W: %-10s %s %6dkm %3d%s  %d\n", c, cwi->wwl1, (int)qrb, (int)qtf, degree, cwi->stamp1);
-		if (wwls && g_hash_table_lookup(wwls, cwi->wwl1) == NULL) g_hash_table_insert(wwls, cwi->wwl1, NULL);
-	}
+        qrbqtf(myqth, cwi->wwl1, &qrb, &qtf, NULL, 0);
+        g_string_sprintfa(gs, "C_W: %-10s %s %6dkm %3d%s  %d\n", c, cwi->wwl1, (int)qrb, (int)qtf, degree, cwi->stamp1);
+        if (wwls && g_hash_table_lookup(wwls, cwi->wwl1) == NULL) g_hash_table_insert(wwls, cwi->wwl1, NULL);
+    }
     if (cwi->qrv>0){
         g_string_append(gs, VTEXT(T_QRV_ON));
         for (i=0;i<26;i++){
