@@ -833,7 +833,7 @@ void menu_qso_check(void *arg){
 
 
 void call_info_map(struct dialog_data *dlg, struct dialog_item_data *di){
-	GString *gs = g_string_new("http://qthlocator.free.fr/index.php?locator=");
+	GString *gs = g_string_new("http://k7fry.com/grid/?qth=");
 	g_string_append(gs, di->item->text);
 	z_browser(gs->str);
 	g_string_free(gs, TRUE);
@@ -1086,15 +1086,22 @@ found:;
 }
 
 char *get_pref(char *buf, char *call){ 
-    char *c0, *c1;
+    char *c0, *c1, *c2;
     
-    c0=c1=NULL;
+    c0=c1=c2=NULL;
     safe_strncpy0(buf, call, 20);
-    if (regmatch(call, "^(.*[0-9])[A-Z]*", &c0, &c1, NULL)==0){
+	if (regmatch(call, "^(.*)[0-9][A-Z]*\\/([0-9])", &c0, &c1, &c2, NULL) == 0){
+		if (c2 != NULL && strlen(c2) == 1 && isdigit(c2[0]))
+		{
+			g_snprintf(buf, 20, "%s%s", c1, c2);
+		}
+	}
+	else if (regmatch(call, "^(.*[0-9])[A-Z]*", &c0, &c1, NULL)==0){
         safe_strncpy0(buf, c1, 20);
     }
     if (c0) g_free(c0);
-    if (c1) g_free(c1);
+	if (c1) g_free(c1);
+	if (c2) g_free(c2);
     dbg("get_pref(%s)='%s'\n", call, buf);
     return buf;
 }
