@@ -67,7 +67,8 @@ void add_qso_str1(GString *gs, struct qso *q, struct band *b){
     g_string_append(gs, z_str_uc(safe_strncpy0(s, q->qsonrr, 5)));
     g_string_append_c(gs, ';');
    
-    g_string_append(gs, z_str_uc(safe_strncpy0(s, q->exc, 7)));
+	safe_strncpy0(s, q->exc, MAX_EXC_LEN+1);
+    g_string_append(gs, z_str_uc(s));
     g_string_append_c(gs, ';');
     
     g_string_append(gs, z_str_uc(safe_strncpy0(s, q->locator, 7)));
@@ -152,7 +153,7 @@ static int write_edi_header(struct band *b, struct config_band *confb, FILE *f){
         g_string_sprintfa(gs, "TDate=%d;%d\r\n", b->stats->first_date, b->stats->last_date); 
     g_string_sprintfa(gs, "PCall=%s\r\n", z_str_uc(safe_strncpy0(s, ctest->pcall, 69)));
     g_string_sprintfa(gs, "PWWLo=%s\r\n", z_str_uc(safe_strncpy0(s, ctest->pwwlo, 69)));
-    g_string_sprintfa(gs, "PExch=%s\r\n", z_str_uc(safe_strncpy0(s, ctest->pexch, 69)));
+	g_string_sprintfa(gs, "PExch=%s\r\n", z_str_uc(safe_strncpy0(s, ctest->pexch, MAX_EXC_LEN+1)));
     g_string_sprintfa(gs, "PAdr1=%s\r\n",    safe_strncpy0(s, ctest->padr1, 69));
     g_string_sprintfa(gs, "PAdr2=%s\r\n",    safe_strncpy0(s, ctest->padr2, 69));
 	g_string_sprintfa(gs, "PSect=%s\r\n", get_psect_str(b));
@@ -634,7 +635,7 @@ static GHashTable *load_edi_until(FILE *f, GHashTable *hash, gchar *until){
             continue;
         }
         g_strstrip(a[0]);
-        g_strstrip(a[1]); 
+        g_strchomp(a[1]); 
 
         k=z_str_lc(g_strdup(a[0]));
         v=g_strdup(a[1]);
@@ -1085,6 +1086,7 @@ destroy:;
             load_ctest_from_mem(ctest, datedir, hash);
 			update_hw();
             maps_reload();
+			maps_update_showwwls();
             chart_reload();
         }
         
