@@ -251,6 +251,9 @@ void read_exc_files(struct excdb *excdb, enum exctype exctype, gchar *excname){
         if (strcasecmp(ename, "wsa")==0) {
             ret = load_vexc_from_mem(excdb, txt_tucnakvexcwsa, sizeof(txt_tucnakvexcwsa));
         }
+        if (strcasecmp(ename, "uba")==0) {
+            ret = load_vexc_from_mem(excdb, txt_tucnakvexcuba, sizeof(txt_tucnakvexcuba));
+        }
         dbg("    %s %d\n", ename, ret);
     }
     g_free(ename);
