@@ -116,13 +116,17 @@ p.stress{
 );
 }
 
-void html_header(GString *gs, gchar *title, int flags, char *bodyarg){
+void html_header(GString *gs, gchar *title, int flags, int refresh, char *bodyarg){
    
 
     g_string_sprintfa(gs, 
 "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\">\n"
 "<html><head>\n"
 "<meta http-equiv=\"content-type\" content=\"text/html; charset=iso-8859-2\">\n"
+    );
+    if (refresh)
+       zg_string_eprintfa("h", gs, "<meta http-equiv=\"refresh\" content=\"%d\">\n", refresh);
+    g_string_sprintfa(gs, 
 "<style type=\"text/css\">\n"
     );
 
@@ -141,7 +145,6 @@ void html_header(GString *gs, gchar *title, int flags, char *bodyarg){
 
 }
 
-    
 void html_ref_header(GString *gs){
     zg_string_eprintfa("h", gs, "<p>%s: %S</p>\n", VTEXT(T_LOCATOR), ctest->pwwlo);
     g_string_sprintfa(gs, "<table class=\"qsos\">\n");
@@ -373,7 +376,7 @@ void html_complete(GString *gs, int flags){
             g_string_sprintf(title, "%s", ctest->pcall);
             z_str_uc(title->str);
             g_string_sprintfa(title, " - %s", ctest->tname);
-            html_header(gs, title->str, 0, NULL);
+            html_header(gs, title->str, 0, cfg->httpd_refresh, NULL);
             html_ref_header(gs);
             header_saved=1;
         }
