@@ -32,14 +32,15 @@ struct httpd *httpd;
 struct httpd *init_httpd(void){
     struct httpd *httpd;
     struct sockaddr_in sin;
-	char errbuf[100];
+    char errbuf[100];
 
     if (!cfg->httpd_enable) return NULL;
 
-  	progress(VTEXT(T_INIT_HTTPD));		
+    progress(VTEXT(T_INIT_HTTPD));      
 
     httpd = g_new0(struct httpd, 1);
     httpd->port = cfg->httpd_port; 
+    httpd->refresh = cfg->httpd_refresh; 
 
     httpd->sock = socket(PF_INET, SOCK_STREAM, IPPROTO_TCP);
     if (httpd->sock < 0){
@@ -47,10 +48,10 @@ struct httpd *init_httpd(void){
         goto x;
     } 
 
-	if (z_sock_reuse(httpd->sock, 1)){
-	    trace(cfg->trace_sock, "Can't set SO_REUSEADDR\n");
+    if (z_sock_reuse(httpd->sock, 1)){
+        trace(cfg->trace_sock, "Can't set SO_REUSEADDR\n");
         goto x;
-	}
+    }
     
     if (z_sock_nonblock(httpd->sock, 1)){
         trace(cfg->trace_sock, "Can't set O_NONBLOCK\n");
@@ -86,7 +87,7 @@ x:;
 void free_httpd(struct httpd *httpd){
     if (!httpd) return;
 
-  	progress(VTEXT(T_FREE_HTTPD));		
+    progress(VTEXT(T_FREE_HTTPD));      
 
     if (httpd->sock >= 0) {
         zselect_set(zsel, httpd->sock, NULL, NULL, NULL, NULL);
@@ -117,9 +118,9 @@ void httpd_accept_handler(void *arg){
     socklen = sizeof(conn->peer);
     sock = accept(httpd->sock, (struct sockaddr *)&conn->peer, &socklen);
     if (!socklen || sock < 0) {
-		g_free(conn);
-		return;
-	}
+        g_free(conn);
+        return;
+    }
 
     trace(cfg->trace_sock, "Accepted socket %d %s:%d\n", sock, inet_ntoa(conn->peer.sin_addr), ntohs(conn->peer.sin_port));
 
@@ -159,10 +160,10 @@ void httpd_read_handler(void *arg){
         break;
     }
     if (lf < 2) return;
-	
-	g_strlcpy(s, conn->request->str, sizeof(s));
-	c = strchr(s, '\r');
-	if (c) *c = '\0';
+    
+    g_strlcpy(s, conn->request->str, sizeof(s));
+    c = strchr(s, '\r');
+    if (c) *c = '\0';
     log_addf("HTTP %s: %s", inet_ntoa(conn->peer.sin_addr), s);
 
     if (strncasecmp(conn->request->str, "GET ", 4) == 0){
@@ -183,54 +184,54 @@ void httpd_write_handler(void *arg){
 
     conn = (struct httpconn*)arg;
 
-	if (conn->response->len > 0){
-		len = conn->response->len;
-		if (len > 1400) len = 1400;
-		ret = send(conn->sock, conn->response->str, len, 0);
-		//err = z_sock_errno;
-		if (ret <= 0){
-			g_ptr_array_remove(httpd->conns, conn);
-			free_httpconn(conn);
-			return;
-		}
+    if (conn->response->len > 0){
+        len = conn->response->len;
+        if (len > 1400) len = 1400;
+        ret = send(conn->sock, conn->response->str, len, 0);
+        //err = z_sock_errno;
+        if (ret <= 0){
+            g_ptr_array_remove(httpd->conns, conn);
+            free_httpconn(conn);
+            return;
+        }
 
-		g_string_erase(conn->response, 0, ret);
-		if (conn->response->len <= 0 && !conn->response_zbb){
-			g_ptr_array_remove(httpd->conns, conn);
-			free_httpconn(conn);
-			return;
-		}
-	}
-	else
-	{
-		if (conn->response_zbb){
-			len = conn->response_zbb->len - conn->response_i;
-			if (len > 1400) len = 1400;
-			ret = send(conn->sock, conn->response_zbb->buf + conn->response_i, len, 0);
-			if (ret <= 0){
-				g_ptr_array_remove(httpd->conns, conn);
-				free_httpconn(conn);
-				return;
-			}
-			conn->response_i += ret;
-			if (conn->response_i >= conn->response_zbb->len){
-				g_ptr_array_remove(httpd->conns, conn);
-				free_httpconn(conn);
-				return;
-			}
-		}
-	}
+        g_string_erase(conn->response, 0, ret);
+        if (conn->response->len <= 0 && !conn->response_zbb){
+            g_ptr_array_remove(httpd->conns, conn);
+            free_httpconn(conn);
+            return;
+        }
+    }
+    else
+    {
+        if (conn->response_zbb){
+            len = conn->response_zbb->len - conn->response_i;
+            if (len > 1400) len = 1400;
+            ret = send(conn->sock, conn->response_zbb->buf + conn->response_i, len, 0);
+            if (ret <= 0){
+                g_ptr_array_remove(httpd->conns, conn);
+                free_httpconn(conn);
+                return;
+            }
+            conn->response_i += ret;
+            if (conn->response_i >= conn->response_zbb->len){
+                g_ptr_array_remove(httpd->conns, conn);
+                free_httpconn(conn);
+                return;
+            }
+        }
+    }
 }
 
 void httpd_header(struct httpconn *conn, int status, char *contenttype){
-	char *ss;
-	if (!contenttype) contenttype = "text/html; charset=iso-8859-2";
-	switch (status){
-		case 200: ss = "OK"; break;
-		case 405: ss = "Not Found";	break;
-		case 500: ss = "Internal server error"; break;
-		default: ss = "Unknown status"; break;
-	}
+    char *ss;
+    if (!contenttype) contenttype = "text/html; charset=iso-8859-2";
+    switch (status){
+        case 200: ss = "OK"; break;
+        case 405: ss = "Not Found"; break;
+        case 500: ss = "Internal server error"; break;
+        default: ss = "Unknown status"; break;
+    }
 
     g_string_sprintf(conn->response, "HTTP/1.1 %d %s\r\n", status, ss);
     g_string_sprintfa(conn->response, "Server: Tucnak-%s %s\r\n", Z_PLATFORM, PACKAGE_VERSION);
@@ -241,7 +242,7 @@ void httpd_header(struct httpconn *conn, int status, char *contenttype){
 }
 
 static void httpd_get_style_css(struct httpconn *conn){
-	g_string_append(conn->response, 
+    g_string_append(conn->response, 
 "body {\n"
 "    font-size: 12pt;\n"
 /*"    font-family: Tahoma, Helvetica, Arial, sans-serif}\n"*/
@@ -298,9 +299,9 @@ p.stress{
 }
 
 static void httpd_get_mem(struct httpconn *conn, const unsigned char *mem, int len){
-	conn->response_zbb = zbinbuf_init();
-	zbinbuf_append_bin(conn->response_zbb, (void*)mem, len);
-	conn->response_i = 0;
+    conn->response_zbb = zbinbuf_init();
+    zbinbuf_append_bin(conn->response_zbb, (void*)mem, len);
+    conn->response_i = 0;
 }
 
 
@@ -312,7 +313,7 @@ static void httpd_get_index(struct httpconn *conn){
     httpd_header(conn, 200, NULL);
 
     if (!ctest){
-        html_header(conn->response, "No contest", HTML_ICON, NULL);
+        html_header(conn->response, "No contest", HTML_ICON, httpd->refresh, NULL);
         g_string_sprintfa(conn->response, "<p>No contest opened</p>\n");
         html_footer(conn->response, 0);
         return;
@@ -322,7 +323,7 @@ static void httpd_get_index(struct httpconn *conn){
     title = g_string_sized_new(200);
     
     zg_string_eprintfa("h", title, "%S - %s", ctest->pcall, ctest->tname);
-    html_header(gs, title->str, HTML_ICON, NULL);
+    html_header(gs, title->str, HTML_ICON, httpd->refresh, NULL);
 
     g_string_sprintfa(gs, "<a href=\"complete\">Complete report</a><br>\n");
     g_string_sprintfa(gs, "<a href=\"search?q=\">QSO search</a><br>\n");
@@ -354,63 +355,63 @@ static void httpd_get_index(struct httpconn *conn){
 }
 
 void httpd_get_stats(struct httpconn *conn, const char *bandchar_str){
-	int i;
-	struct band *b;
+    int i;
+    struct band *b;
 
-	httpd_header(conn, 200, NULL);
-	if (!ctest){
-        html_header(conn->response, VTEXT(T_NO_CTEST), HTML_ICON, NULL); 
+    httpd_header(conn, 200, NULL);
+    if (!ctest){
+        html_header(conn->response, VTEXT(T_NO_CTEST), HTML_ICON, httpd->refresh, NULL); 
         g_string_append(conn->response, VTEXT(T_NO_CONTEST_OPENED));
         html_footer(conn->response, 0);
         return;
     }
-	b = find_band_by_bandchar(bandchar_str[0]);
-	if (!b){
-        html_header(conn->response, VTEXT(T_BAND_NOT_FOUND), HTML_ICON, NULL); 
-		g_string_sprintfa(conn->response, VTEXT(T_BAND_NOT_FOUND), bandchar_str[0]);
+    b = find_band_by_bandchar(bandchar_str[0]);
+    if (!b){
+        html_header(conn->response, VTEXT(T_BAND_NOT_FOUND), HTML_ICON, httpd->refresh, NULL); 
+        g_string_sprintfa(conn->response, VTEXT(T_BAND_NOT_FOUND), bandchar_str[0]);
         html_footer(conn->response, 0);
-		return;
-	}
+        return;
+    }
 
-    html_header(conn->response, VTEXT(T_STATS), HTML_ICON, NULL); 
+    html_header(conn->response, VTEXT(T_STATS), HTML_ICON, httpd->refresh, NULL); 
     g_string_sprintfa(conn->response, "<pre>");
-	for (i = 0; i < b->statsfifo1->items->len ; i++){
-		char *s = (char*)g_ptr_array_index(b->statsfifo1->items, i);
-		g_string_sprintfa(conn->response, "%s\n", s);
-	}
+    for (i = 0; i < b->statsfifo1->items->len ; i++){
+        char *s = (char*)g_ptr_array_index(b->statsfifo1->items, i);
+        g_string_sprintfa(conn->response, "%s\n", s);
+    }
     g_string_sprintfa(conn->response, "</pre>");
     html_footer(conn->response, 0);
 
 }
 
 void httpd_get_qsos(struct httpconn *conn, const char *bandchar_str){
-	struct band *b;
+    struct band *b;
     struct config_band *confb;
-	char bandchar;
-	struct subwin *map, *chart;
-	
+    char bandchar;
+    struct subwin *map, *chart;
+    
     httpd_header(conn, 200, NULL);
-	if (!ctest){
-        html_header(conn->response, VTEXT(T_NO_CTEST), HTML_ICON, NULL); 
+    if (!ctest){
+        html_header(conn->response, VTEXT(T_NO_CTEST), HTML_ICON, httpd->refresh, NULL); 
         g_string_append(conn->response, VTEXT(T_NO_CONTEST_OPENED));
         html_footer(conn->response, 0);
         return;
     }
-	bandchar = z_char_uc(bandchar_str[0]);
-	b = find_band_by_bandchar(bandchar);
+    bandchar = z_char_uc(bandchar_str[0]);
+    b = find_band_by_bandchar(bandchar);
     confb = get_config_band_by_bandchar(bandchar);
-	if (!b || !confb){
-        html_header(conn->response, VTEXT(T_BAND_NOT_FOUND), HTML_ICON, NULL); 
-		g_string_sprintfa(conn->response, VTEXT(T_BAND_C_NOT_FOUND), bandchar_str[0]);
+    if (!b || !confb){
+        html_header(conn->response, VTEXT(T_BAND_NOT_FOUND), HTML_ICON, httpd->refresh, NULL); 
+        g_string_sprintfa(conn->response, VTEXT(T_BAND_C_NOT_FOUND), bandchar_str[0]);
         html_footer(conn->response, 0);
-		return;
-	}
+        return;
+    }
 
-	map = sw_raise_or_new(SWT_MAP);
-	chart = sw_raise_or_new(SWT_CHART);
+    map = sw_raise_or_new(SWT_MAP);
+    chart = sw_raise_or_new(SWT_CHART);
 
     if (map || chart){
-        html_header(conn->response, "QSOs", HTML_ICON, NULL); 
+        html_header(conn->response, "QSOs", HTML_ICON, httpd->refresh, NULL); 
         html_band_header(conn->response, b, confb, HTML_ICON | HTML_IMG_ROOT, map, chart);
         html_qsos(conn->response, b, confb);
         html_band_footer(conn->response);
@@ -420,8 +421,8 @@ void httpd_get_qsos(struct httpconn *conn, const char *bandchar_str){
 
 void httpd_get_complete(struct httpconn *conn){
     httpd_header(conn, 200, NULL);
-	if (!ctest){
-        html_header(conn->response, VTEXT(T_NO_CTEST), HTML_ICON, NULL); 
+    if (!ctest){
+        html_header(conn->response, VTEXT(T_NO_CTEST), HTML_ICON, httpd->refresh, NULL); 
         g_string_append(conn->response, VTEXT(T_NO_CONTEST_OPENED));
         html_footer(conn->response, 0);
         return;
@@ -431,83 +432,83 @@ void httpd_get_complete(struct httpconn *conn){
 
 #ifdef Z_HAVE_SDL
 void httpd_get_map(struct httpconn *conn, char bandchar){
-	struct band *band;
-	struct subwin *map;
-	int ret, oldaa;
+    struct band *band;
+    struct subwin *map;
+    int ret, oldaa;
 
 
-	band = find_band_by_bandchar(bandchar);
-	if (!band){
-		httpd_header(conn, 404, NULL);
-		return;
-	}
-	map = sw_raise_or_new(SWT_MAP);
+    band = find_band_by_bandchar(bandchar);
+    if (!band){
+        httpd_header(conn, 404, NULL);
+        return;
+    }
+    map = sw_raise_or_new(SWT_MAP);
     if (!map || !map->screen) {
-		httpd_header(conn, 404, NULL);
-		return;
+        httpd_header(conn, 404, NULL);
+        return;
     }
 
-	oldaa = zsdl->antialiasing;
-	if (zsdl->antialiasing_supported) zsdl->antialiasing = 1;
+    oldaa = zsdl->antialiasing;
+    if (zsdl->antialiasing_supported) zsdl->antialiasing = 1;
 
-	map->gdirty = 1;
-	map_for_photo(map, band, 0);
-	map_recalc_gst(map, band);
-	sw_map_redraw(map, band, HTML_FOR_PHOTO);
+    map->gdirty = 1;
+    map_for_photo(map, band, 0);
+    map_recalc_gst(map, band);
+    sw_map_redraw(map, band, HTML_FOR_PHOTO);
 
-	conn->response_zbb = zbinbuf_init();
-	ret = zpng_save(map->screen, NULL, conn->response_zbb);
-	if (ret){
-		zbinbuf_free(conn->response_zbb);
-		conn->response_zbb = NULL;
-		httpd_header(conn, 500, NULL);
-		zsdl->antialiasing = oldaa;
-		return;
-	}
-	httpd_header(conn, 200, "image/png");
+    conn->response_zbb = zbinbuf_init();
+    ret = zpng_save(map->screen, NULL, conn->response_zbb);
+    if (ret){
+        zbinbuf_free(conn->response_zbb);
+        conn->response_zbb = NULL;
+        httpd_header(conn, 500, NULL);
+        zsdl->antialiasing = oldaa;
+        return;
+    }
+    httpd_header(conn, 200, "image/png");
 
-	zsdl->antialiasing = oldaa;
-	map_recalc_gst(map, aband);
+    zsdl->antialiasing = oldaa;
+    map_recalc_gst(map, aband);
 }
 
 void httpd_get_chart(struct httpconn *conn, char bandchar){
-	struct band *band;
-	struct subwin *chart;
-	int ret;
+    struct band *band;
+    struct subwin *chart;
+    int ret;
 
-	band = find_band_by_bandchar(bandchar);
-	if (!band){
-		httpd_header(conn, 404, NULL);
-		return;
-	}
-	chart = sw_raise_or_new(SWT_CHART);
+    band = find_band_by_bandchar(bandchar);
+    if (!band){
+        httpd_header(conn, 404, NULL);
+        return;
+    }
+    chart = sw_raise_or_new(SWT_CHART);
     if (!chart || !chart->screen) {
-		httpd_header(conn, 404, NULL);
-		return;
+        httpd_header(conn, 404, NULL);
+        return;
     }
 
-	chart->gdirty = 1;
-	sw_chart_recalc_extremes(chart, band);
-	sw_chart_redraw(chart, band, HTML_FOR_PHOTO);
+    chart->gdirty = 1;
+    sw_chart_recalc_extremes(chart, band);
+    sw_chart_redraw(chart, band, HTML_FOR_PHOTO);
 
-	conn->response_zbb = zbinbuf_init();
-	ret = zpng_save(chart->screen, NULL, conn->response_zbb);
-	if (ret){
-		zbinbuf_free(conn->response_zbb);
-		conn->response_zbb = NULL;
-		httpd_header(conn, 500, NULL);
-		return;
-	}
-	httpd_header(conn, 200, "image/png");
-	sw_chart_recalc_extremes(chart, aband);
+    conn->response_zbb = zbinbuf_init();
+    ret = zpng_save(chart->screen, NULL, conn->response_zbb);
+    if (ret){
+        zbinbuf_free(conn->response_zbb);
+        conn->response_zbb = NULL;
+        httpd_header(conn, 500, NULL);
+        return;
+    }
+    httpd_header(conn, 200, "image/png");
+    sw_chart_recalc_extremes(chart, aband);
 }
 
 #endif
 
 void httpd_search_form(struct httpconn *conn){
-	int i, nqsos = 0;
-	time_t now;
-	struct tm *tm;
+    int i, nqsos = 0;
+    time_t now;
+    struct tm *tm;
     GString *gs = conn->response;
 
     zg_string_eprintfa("h", gs,  
@@ -518,21 +519,21 @@ void httpd_search_form(struct httpconn *conn){
 "</form>\n", 
     ctest->pcall, ctest->tname);
 
-	
-	for (i = 0; i < ctest->bands->len; i++){
-		struct band *b = (struct band *)g_ptr_array_index(ctest->bands, i);
-		nqsos += b->stats->nqsos;
-	}
-	now = time(NULL);
-	tm = gmtime(&now);
+    
+    for (i = 0; i < ctest->bands->len; i++){
+        struct band *b = (struct band *)g_ptr_array_index(ctest->bands, i);
+        nqsos += b->stats->nqsos;
+    }
+    now = time(NULL);
+    tm = gmtime(&now);
 
-	zg_string_eprintfa("h", gs,  
+    zg_string_eprintfa("h", gs,  
 "<div class=\"info\">%d %s | "
 "%d.%d.%d | %02d:%02d UTC</div> "
 "<br><br><br>",
     nqsos, 
-	VTEXT(T_QSOS_IN_DATABASE),
-	tm->tm_mday, tm->tm_mon + 1, tm->tm_year + 1900, tm->tm_hour, tm->tm_min);
+    VTEXT(T_QSOS_IN_DATABASE),
+    tm->tm_mday, tm->tm_mon + 1, tm->tm_year + 1900, tm->tm_hour, tm->tm_min);
 }
 
 /*void httpd_search(struct httpconn *conn){
@@ -540,10 +541,10 @@ void httpd_search_form(struct httpconn *conn){
 
     httpd_header(conn, 200, NULL);
 
-	if (!ctest){
+    if (!ctest){
         html_header(conn->response, "No contest", HTML_ICON | HTML_CENTER, NULL); 
         g_string_sprintfa(conn->response, "<p>No contest opened</p>\n");
-	    g_string_append(gs, "<br><br><br>\n");
+        g_string_append(gs, "<br><br><br>\n");
         html_footer(conn->response, HTML_CENTER);
         return;
     }
@@ -551,41 +552,41 @@ void httpd_search_form(struct httpconn *conn){
 
 
     html_header(gs, "Tucnak online log", HTML_ICON | HTML_CENTER, "onLoad=\"document.getElementById('q').focus();\"");
-	httpd_search_form(conn);
-	g_string_append(gs, "<br><br><br>\n");
+    httpd_search_form(conn);
+    g_string_append(gs, "<br><br><br>\n");
     html_footer(conn->response, HTML_CENTER);
 } */
 
 void httpd_search(struct httpconn *conn, char *call){
-	int i, j, found = 0;
-	char *c;
-	GString *gs = conn->response;
-	GString *call2 = g_string_new("");
+    int i, j, found = 0;
+    char *c;
+    GString *gs = conn->response;
+    GString *call2 = g_string_new("");
 
-	for (c = call; *c != '\0'; c++){
-		if (*c != '%') {
-			g_string_append_c(call2, *c);
-			continue;
-		}
-		if (strncmp(c, "%2F", 3) == 0){
-			g_string_append(call2, "/");
-			c += 2;
-			continue;
-		}
-		// skip other %..
-	}
+    for (c = call; *c != '\0'; c++){
+        if (*c != '%') {
+            g_string_append_c(call2, *c);
+            continue;
+        }
+        if (strncmp(c, "%2F", 3) == 0){
+            g_string_append(call2, "/");
+            c += 2;
+            continue;
+        }
+        // skip other %..
+    }
 
     httpd_header(conn, 200, NULL);
 
-	if (!ctest){
-        html_header(conn->response, VTEXT(T_NO_CTEST), HTML_ICON|HTML_CENTER, NULL);
+    if (!ctest){
+        html_header(conn->response, VTEXT(T_NO_CTEST), HTML_ICON|HTML_CENTER, httpd->refresh, NULL);
         g_string_append(conn->response, VTEXT(T_NO_CONTEST_OPENED));
-	    g_string_append(gs, "<br><br><br>\n");
+        g_string_append(gs, "<br><br><br>\n");
         html_footer(conn->response, HTML_CENTER);
         return;
     }
-	html_header(gs, VTEXT(T_TUCNAK_ONLINE_LOG), HTML_ICON | HTML_CENTER, "onLoad=\"document.getElementById('q').focus();\""); 
-	httpd_search_form(conn);
+    html_header(gs, VTEXT(T_TUCNAK_ONLINE_LOG), HTML_ICON | HTML_CENTER, httpd->refresh, "onLoad=\"document.getElementById('q').focus();\""); 
+    httpd_search_form(conn);
 
     /*zg_string_eprintfa("h", gs,  
 "<div id=\"calltest\">%s - %s</div>\n",
@@ -613,21 +614,21 @@ void httpd_search(struct httpconn *conn, char *call){
         }
 
         g_string_append(gs, "</table>");
-        if (!found > 0) g_string_sprintfa(gs, "<p><b>%s</b></p>\n", VTEXT(T_CALL_NOT_FOUND));
+        if (!found) g_string_sprintfa(gs, "<p><b>%s</b></p>\n", VTEXT(T_CALL_NOT_FOUND));
     }
-	g_string_append(gs, "<br><br><br>\n");
+    g_string_append(gs, "<br><br><br>\n");
     html_footer(conn->response, HTML_CENTER);
-	g_string_free(call2, TRUE);
+    g_string_free(call2, TRUE);
 }
 
 void httpd_get(struct httpconn *conn){
-	char *c, *page, *tmp, *page0, *page1/*, *page2*/;
-	
+    char *c, *page, *tmp, *page0, *page1/*, *page2*/;
+    
     tmp = NULL;
-	page = conn->request->str + strlen("GET") + 1;
-	while (*page == ' ') page++;
-	c = strchr(page, ' ');
-	if (c != NULL) *c = '\0';
+    page = conn->request->str + strlen("GET") + 1;
+    while (*page == ' ') page++;
+    c = strchr(page, ' ');
+    if (c != NULL) *c = '\0';
 
     if (strcmp(page, "/") == 0){
         if (cfg->httpd_show_priv){
@@ -638,9 +639,9 @@ void httpd_get(struct httpconn *conn){
         return;
     }
 
-	page0 = strtok_r(page, "/", &tmp);
-	page1 = strtok_r(NULL, "/", &tmp);
-	//page2 = strtok_r(NULL, "/", &tmp);
+    page0 = strtok_r(page, "/", &tmp);
+    page1 = strtok_r(NULL, "/", &tmp);
+    //page2 = strtok_r(NULL, "/", &tmp);
     if (cfg->httpd_show_priv){
         // private web - all informations
         if (strcmp(page0, "style.css") == 0){
