@@ -13,7 +13,9 @@
 #include "ac.h"
 #include "alsa.h"
 #include "charsets.h"
-#include "cor.h"
+#ifdef Z_HAVE_SDL
+#include "cordata.h"
+#endif
 #include "cwdaemon.h"
 #include "cwdb.h"
 #include "davac4.h"
@@ -30,6 +32,7 @@
 #include "kbd.h"
 #include "language2.h"
 #include "main.h"
+#include "map.h"
 #include "masterdb.h"
 #include "menu.h"
 #include "misc.h"
@@ -54,6 +57,7 @@
 #include "trig.h"
 //#include "update.h"
 #include "vhfcontestnet.h"
+#include "slovhfnet.h"
 #include "wizz.h"
 
 #ifdef ANDROID
@@ -353,7 +357,7 @@ static void main_msg_handler(struct zselect *zsel, int n, char **items){
     }
     if (strcmp(items[0], "COR")==0){
 #ifdef Z_HAVE_SDL
-        cor_read_handler(n, items);
+        zcor_read_handler(n, items);
 #endif
         return;
     }
@@ -666,7 +670,7 @@ static void init(void)
 #endif
 #ifdef Z_HAVE_SDL    
 	progress(VTEXT(T_INIT_MAP));		
-    gcor = init_cor();
+    gcor = zcor_init(zsel, map_cor_callback, cor_tucnakcor, COR_ITEMS);
 #endif
 
     if (cfg->dssaver){
@@ -783,7 +787,7 @@ static void terminate_all_subsystems(void)
 	zbat_free(gbat);
 	free_acs(gacs); gacs = NULL;
 	progress(VTEXT(T_FREE_MAP));		
-    free_cors();
+    zcors_free();
 #endif
 #ifdef USE_SDR
 	free_sdr(gsdr);
@@ -863,6 +867,7 @@ void redraw(void){
 
 int main(int argc, char *argv[])
 {
+	//zavgfilter_test();
 #if 0
     GString *gs = g_string_sized_new(8000);
     z_backtrace_symbols(gs, NULL, 0);
@@ -1131,7 +1136,7 @@ int main(int argc, char *argv[])
 //    MessageBox(NULL, "Hello World, I'm Tucnak compiled under mingw", "Info", MB_OK);
 
 #endif
-#ifdef Z_UNIX_ANDROID
+#if defined(Z_UNIX_ANDROID) && !defined(Z_MACOS)
     starting_sbrk = (char *)sbrk(0);
 #endif
 #ifdef ANDROID
