@@ -44,6 +44,7 @@
 #include "tregex.h"
 #include "update.h"
 #include "vhfcontestnet.h"
+#include "slovhfnet.h"
 #ifdef VOIP
 #include "voip.h"
 #endif
@@ -521,7 +522,7 @@ void memory_info(void *arg)
         fclose(f);
     }
     p += sprintf(p, "\n");
-#ifdef Z_UNIX_ANDROID
+#if defined(Z_UNIX_ANDROID) && !defined(Z_MACOS)
     act_sbrk = (char *)sbrk(0);
     p += sprintf(p, VTEXT(T_SBRK), act_sbrk-starting_sbrk);
 #endif
@@ -829,7 +830,7 @@ void subwins_menu(void *arg)
                 add_to_menu(&mi, g_strdup(VTEXT(T_OPEN_CONNECTION)), "", VTEXT(T_HK_OPEN_CONNECTION), kst_open_connection, sw, 0);
                 add_to_menu(&mi, g_strdup(VTEXT(T_KILL_CONNECTION)), "", VTEXT(T_HK_KILL_CONNECTION), menu_kill_connection, sw, 0);
                 add_to_menu(&mi, g_strdup(VTEXT(T_EXPORT_TO_TEXT_FILE)), "", VTEXT(T_HK_EXPORT_TO_TEXT_FILE), kst_export_text, sw, 0);
-				add_to_menu(&mi, g_strdup("OK1MZM: >>>> Press HERE <<<<"), "", "D", kst_dump_skip, sw, 0);
+				//add_to_menu(&mi, g_strdup("OK1MZM: >>>> Press HERE <<<<"), "", "D", kst_dump_skip, sw, 0);
                 sep = 1;
                 break;
             case SWT_DXC:
@@ -1137,7 +1138,8 @@ static struct menu_item ctest_menu2[] = {
     {CTEXT(T_QSO_CHECK),      "", CTEXT(T_HK_QSO_CHECK), MENU_FUNC menu_qso_check, NULL, 0, 0},
     {"", "", M_BAR, NULL, NULL, 0, 0},
     {CTEXT(T_EXPORT_EDI),     "",  CTEXT(T_HK_EXPORT_EDI), MENU_FUNC menu_export_edi, NULL, 0, 0},
-	{CTEXT(T_UPLOAD_TO_VHFNET), "", CTEXT(T_HK_UPLOAD_TO_VHFNET), MENU_FUNC vhfcontestnet_upload, NULL, 0, 0},
+	{CTEXT(T_UPLOAD_TO_SLOVHF), "", CTEXT(T_HK_UPLOAD_TO_SLOVHF), MENU_FUNC slovhfnet_upload, NULL, 0, 0},
+	//{CTEXT(T_UPLOAD_TO_VHFNET), "", CTEXT(T_HK_UPLOAD_TO_VHFNET), MENU_FUNC vhfcontestnet_upload, NULL, 0, 0},
     {CTEXT(T_EXPORT_REPORT),  "",  CTEXT(T_HK_EXPORT_REPORT), MENU_FUNC menu_export_report, NULL, 0, 0},
     {CTEXT(T_EXPORT_ADIF),    "",  CTEXT(T_HK_EXPORT_ADIF), MENU_FUNC menu_export_adif, NULL, 0, 0},
     {CTEXT(T_EXPORT_HTML),    "",  CTEXT(T_HK_EXPORT_HTML), MENU_FUNC menu_export_html, NULL, 0, 0},
