@@ -49,7 +49,7 @@ char dxcbonu_str[MAX_STR_LEN], dxcmult_str[MAX_STR_LEN];
 int prefglob;
 int rstused, defrstr;
 char default_rst[MAX_STR_LEN],default_rs[MAX_STR_LEN];
-char operator_[EQSO_LEN];
+static char operator_[EQSO_LEN];
 int tttype;
 char tttype_str[MAX_STR_LEN];
 int expmode;
@@ -902,7 +902,7 @@ void wizz_func (void *arg){
     safe_strncpy0(pclub, cfg->pclub, 20);z_str_uc(pclub);
     safe_strncpy0(operator_, cfg->operator_, EQSO_LEN);z_str_uc(operator_);
     safe_strncpy0(pwwlo, cfg->pwwlo, 9); z_str_uc(pwwlo);
-    safe_strncpy0(pexch, wi->pexch, 9); z_str_uc(pexch);
+	safe_strncpy0(pexch, wi->pexch, MAX_EXC_LEN+1); z_str_uc(pexch);
     g_snprintf(tdate, MAX_STR_LEN, "%d%02d%02d", 1900+utc.tm_year, 1+utc.tm_mon, utc.tm_mday);
     qsoused=wi->qsoused;
     g_snprintf(qsomult_str,10, "%d", wi->qsomult);
@@ -1135,6 +1135,7 @@ void init_ctest2(int from_dlg, int updloc, struct zstring *zs2, struct wizz_item
             recalc_all_qrbqtf(ctest);
             map_recalc_cors();
             maps_reload();
+			maps_update_showwwls();
 #endif   
             chart_reload();
             //qrv_recalc_wkd(qrvdb); probably not needed
@@ -1174,6 +1175,7 @@ void init_ctest2(int from_dlg, int updloc, struct zstring *zs2, struct wizz_item
 	if (zs == NULL){ 
 		// called from menu, read prepared ~/tucnak/qrv
 		c = g_strconcat(tucnak_dir, "/qrv", NULL);
+		z_wokna(c);
 		load_qrv_from_file(qrv, c);
 		g_free(c);
 	}
@@ -1297,7 +1299,7 @@ void contest_options1(char *title, int from_ctest, struct wizz_item *wi)
     d->items[i].msg = CTEXT(T_YOURWWL);
     
     d->items[++i].type = D_FIELD;
-    d->items[i].dlen = 9;
+    d->items[i].dlen = MAX_EXC_LEN+1;
     d->items[i].data = pexch;
     d->items[i].msg = CTEXT(T_YOUREXC);
     
@@ -1587,7 +1589,7 @@ void contest_options1_from_menu(void *arg)
     safe_strncpy0(pcall, cfg->pcall, 20);z_str_uc(pcall);
     safe_strncpy0(pclub, cfg->pclub, 20);z_str_uc(pclub);
     safe_strncpy0(pwwlo, cfg->pwwlo, 9); z_str_uc(pwwlo);
-    safe_strncpy0(pexch, cfg->pexch, 9); z_str_uc(pexch);
+    safe_strncpy0(pexch, cfg->pexch, MAX_EXC_LEN+1); z_str_uc(pexch);
     g_snprintf(tdate, MAX_STR_LEN, "%d%02d%02d", 1900+utc.tm_year, 1+utc.tm_mon, utc.tm_mday);
     qsoused=1;
     safe_strncpy(qsomult_str,"1", 10);
@@ -1634,7 +1636,7 @@ void contest_options1_from_ctest(void *arg)
     safe_strncpy0(pcall, ctest->pcall, 20);z_str_uc(pcall);
     safe_strncpy0(pclub, ctest->pclub, 20);z_str_uc(pclub);
     safe_strncpy0(pwwlo, ctest->pwwlo, 9); z_str_uc(pwwlo);
-    safe_strncpy0(pexch, ctest->pexch, 9); z_str_uc(pexch);
+    safe_strncpy0(pexch, ctest->pexch, MAX_EXC_LEN+1); z_str_uc(pexch);
     safe_strncpy0(tdate, "", MAX_STR_LEN); 
     qsoused=ctest->qsoused;
     g_snprintf(qsomult_str,10, "%d", ctest->qsomult);
@@ -1686,7 +1688,7 @@ char padr1[MAX_STR_LEN],padr2[MAX_STR_LEN];
 int global_operator;
 char dxc_host[MAX_STR_LEN], dxc_port_str[EQSO_LEN];
 char dxc_user[MAX_STR_LEN], dxc_pass[MAX_STR_LEN];
-char kst_user[MAX_STR_LEN], kst_pass[MAX_STR_LEN], kst_name[MAX_STR_LEN];
+char kst_user[MAX_STR_LEN], kst_pass[MAX_STR_LEN], kst_name[MAX_STR_LEN], slovhf_user[MAX_STR_LEN];
 char contest_def_is_first = 0;
 
 void refresh_contest_def(void *xxx)
@@ -1712,6 +1714,7 @@ void refresh_contest_def(void *xxx)
 	STORE_STR(cfg, kst_user);
 	STORE_STR(cfg, kst_pass);
 	STORE_STR(cfg, kst_name);
+	STORE_STR(cfg, slovhf_user);
 
 	if (contest_def_is_first){
 		g_free(cfg->operator_);		cfg->operator_ = g_strdup(pcall);
@@ -1725,6 +1728,8 @@ void refresh_contest_def(void *xxx)
 
 #ifdef Z_HAVE_SDL
     if (updloc) maps_reload();
+	maps_update_showwwls();
+
 #endif
 	if (first_contest_def){
 		if (strlen(cfg->pcall)==0 || strlen(cfg->pwwlo)==0){
@@ -1794,7 +1799,7 @@ void contest_def(void *pfirst)
 
     safe_strncpy0(padr1,cfg->padr1,MAX_STR_LEN);
     safe_strncpy0(padr2,cfg->padr2,MAX_STR_LEN);
-    safe_strncpy0(pexch,cfg->pexch,MAX_STR_LEN);
+	safe_strncpy0(pexch, cfg->pexch, MAX_EXC_LEN+1);
     safe_strncpy0(default_rs, cfg->default_rs,MAX_STR_LEN);  z_str_uc(default_rs);
     safe_strncpy0(default_rst,cfg->default_rst,MAX_STR_LEN); z_str_uc(default_rst);
 
@@ -1805,6 +1810,7 @@ void contest_def(void *pfirst)
 	safe_strncpy0(kst_user, cfg->kst_user, MAX_STR_LEN);
 	safe_strncpy0(kst_pass, cfg->kst_pass, MAX_STR_LEN);
 	safe_strncpy0(kst_name, cfg->kst_name, MAX_STR_LEN);
+	safe_strncpy0(slovhf_user, cfg->slovhf_user, MAX_STR_LEN);
 
 
     if (!(d = (struct dialog *)g_new0(struct dialog, 30))) return;
@@ -1974,6 +1980,12 @@ void contest_def(void *pfirst)
 		d->items[i].data = kst_name;
 		d->items[i].maxl = 15;
 		d->items[i].msg = CTEXT(T_KST_YOURNAME);
+
+		d->items[++i].type = D_FIELD;
+		d->items[i].dlen = MAX_STR_LEN;
+		d->items[i].data = slovhf_user;
+		d->items[i].maxl = 15;
+		d->items[i].msg = CTEXT(T_SLOVHF_USER);
 		d->items[i].wrap = 1;
 	}
 
