@@ -718,7 +718,7 @@ void rig_opts_fn(struct dialog_data *dlg)
 {
     if (new_model > 0){
         dbg("new_model_str=%d (%s)\n", new_model, new_model_name);
-        if (strlen(dlg->items[1].cdata) == 0) safe_strncpy0(dlg->items[1].cdata, new_model_name, EQSO_LEN);
+        if (strlen(dlg->items[1].cdata) == 0) g_strlcpy(dlg->items[1].cdata, new_model_name, EQSO_LEN);
 		g_snprintf(dlg->items[3].cdata, EQSO_LEN, "%d", new_model);
         new_model = 0;
     }
