@@ -54,9 +54,11 @@ struct qrvdb *init_qrv(void){
     }    
     /*qrv->sort = qrv_compare_call;
     qrv->sort2 = NULL;*/
-    qrvdb->sort = qrv_compare_wkd;
-    qrvdb->sort2 = qrv_compare_qrb;
-    qrvdb->showall = 0;
+    //qrvdb->sort = qrv_compare_wkd;
+    //qrvdb->sort2 = qrv_compare_qrb;
+	qrvdb->sort = qrv_compare_qrb;
+	qrvdb->sort2 = qrv_compare_qrb;
+	qrvdb->showall = 0;
     strcpy(qrvdb->search, "");
     return qrvdb;
 }
@@ -174,6 +176,33 @@ struct qrv_item *qrv_add(gchar *call, gchar *wwl, int qrv_int, int wkd[32], cons
     return qi;
 }
 
+struct qrv_item *qrv_kst_add(char *call, char *wwl){
+	int i, qrv_int = 0, wkd[32];
+	struct qrv_item *ret;
+
+	memset(wkd, 0, sizeof(wkd));
+
+	if (ctest != NULL){
+		for (i = 0; i < ctest->bands->len; i++){
+			struct band *b = (struct band *)g_ptr_array_index(ctest->bands, i);
+			if (b->readonly == 0) qrv_int |= (1 << b->bi);
+		}
+	}
+	else{
+		for (i = 0; i < cfg->bands->len; i++){
+			int bi;
+			struct config_band *cb = (struct config_band *)g_ptr_array_index(cfg->bands, i);
+			if (cb->qrvnow == 0) continue;
+			bi = toupper(cb->bandchar) - 'A';
+			qrv_int |= (1 << bi);
+		}
+	}
+
+	ret = qrv_add(call, wwl, qrv_int, wkd, "@KST", time(NULL));
+	sw_qrv_sort(qrv);
+	return ret;
+}
+
 void qrv_delete(char *call, int bi){
 	struct qrv_item *qi;
 
@@ -281,6 +310,8 @@ int load_qrv_from_file(struct qrvdb *qrvdb, gchar *filename){
     FILE *f;
     char s[202];
 
+	clear_qrv(qrvdb);
+
     f = fopen(filename, "rt");
     if (!f){
         return -1;
@@ -295,6 +326,9 @@ int load_qrv_from_file(struct qrvdb *qrvdb, gchar *filename){
 			old_load_one_qrv(qrvdb,s);
     }
     fclose(f);
+
+	if (ctest->wwlmult > 0) qrv->sort = qrv_compare_wwl;
+
     z_ptr_array_qsort(qrv->qrvs, qrv->sort);
     return 0;
 }
@@ -352,7 +386,7 @@ int qrv_skip(struct qrv_item *qi, int bi, int setdrawn){
 
     if ((qi->bands_wkd & (1<<bi))!=0) ret = 2;
     if (qrv->showall && !*qrv->search) {
-		qi->ac_drawn = 1;
+		//qi->ac_drawn = 1;
 		return ret;
 	}
     if ((qi->bands_qrv & (1<<bi))==0) ret = 1;
@@ -363,8 +397,8 @@ int qrv_skip(struct qrv_item *qi, int bi, int setdrawn){
         if (z_strcasestr(qi->text, qrv->search + 1)) ret = 0;
     }
     //dbg("qrv_skip(%s, %d)=%d  qrv=0x%x  wkd=0x%x\n", qi->call, bi, ret, qi->bands_qrv, qi->bands_wkd);
-	qi->ac_drawn = (ret == 0);
-	if (qi->ac_drawn == 0) qi->ac_start = (time_t)0;
+	//qi->ac_drawn = (ret == 0);
+	//if (qi->ac_drawn == 0) qi->ac_start = (time_t)0;
     return ret;
 }
 
@@ -477,7 +511,9 @@ int qrv_compare_ac_start(const void *a, const void *b){
     if (!*qa && !*qb) return 0;
     if (!*qa) return -qrv->sortdir;
     if (!*qb) return +qrv->sortdir;
-    if (!aband) return 0;
+	//if (!(*qa)->ac_start) return -qrv->sortdir;
+	//if (!(*qb)->ac_start) return +qrv->sortdir;
+	if (!aband) return 0;
     ret = (int)((*qa)->ac_start - (*qb)->ac_start); 
     if (ret) return ret * qrv->sortdir;
     if (qrv->sort2 == qrv_compare_ac_start) return 0;
@@ -512,7 +548,7 @@ int qrv_compare_ac_n(const void *a, const void *b){
     if (!*qa) return -qrv->sortdir;
     if (!*qb) return +qrv->sortdir;
     if (!aband) return 0;
-    ret = (*qa)->ac_interval - (*qb)->ac_interval; 
+    ret = (*qa)->ac_n - (*qb)->ac_n; 
     if (ret) return (-ret) * qrv->sortdir;
     if (qrv->sort2 == qrv_compare_ac_n) return 0;
     return qrv->sort2(a, b);
@@ -538,14 +574,12 @@ int qrv_compare_text(const void *a, const void *b){
 void sw_qrv_seek(struct subwin *sw, int value){
     struct qrv_item *qi;
 
-    if (!aband) return;
-
     while (value > 0){
         sw->cur++;
         if (sw->cur >= qrv->qrvs->len) break;
 		if (sw->cur >= 0){
 			qi = (struct qrv_item *)z_ptr_array_index(qrv->qrvs, sw->cur);
-			if (qrv_skip(qi, aband->bi, 0)) continue;
+			if (aband && qrv_skip(qi, aband->bi, 0)) continue;
 		}
         value--;
     }
@@ -555,7 +589,7 @@ void sw_qrv_seek(struct subwin *sw, int value){
         if (sw->cur < 0) break;
 		if (sw->cur < qrv->qrvs->len){
 			qi = (struct qrv_item *)z_ptr_array_index(qrv->qrvs, sw->cur);
-			if (qrv_skip(qi, aband->bi, 0)) continue;
+			if (aband && qrv_skip(qi, aband->bi, 0)) continue;
 		}
         value++;
     }
@@ -577,8 +611,6 @@ int sw_qrv_kbd_func(struct subwin *sw, struct event *ev, int fw){
     int len;
     struct qrv_item *qi;
     
-    if (!aband) return 0;
-    
     switch(kbd_action(KM_MAIN,ev)){
         case ACT_ESC:
             return 0;
@@ -622,6 +654,7 @@ int sw_qrv_kbd_func(struct subwin *sw, struct event *ev, int fw){
             redraw_later();
             return 1;
         case ACT_ENTER:
+			if (aband == NULL) break;
             if (*qrv->search){
                 strcpy(qrv->search, "");
                 redraw_later();
@@ -652,6 +685,7 @@ int sw_qrv_kbd_func(struct subwin *sw, struct event *ev, int fw){
             redraw_later();
             return 1;
         case ACT_DELETE:
+			if (!aband) break;
 			if (sw->cur < 0 || sw->cur >= qrv->qrvs->len) break;
 		    qi = (struct qrv_item*)z_ptr_array_index(qrv->qrvs, sw->cur);
 			if (!qi) break;
@@ -682,6 +716,7 @@ int sw_qrv_kbd_func(struct subwin *sw, struct event *ev, int fw){
 
             switch(ev->x){
                 case ' ':
+					if (!aband) break;
 					if (sw->cur < 0 || sw->cur >= qrv->qrvs->len) break;
                     qi = (struct qrv_item*)z_ptr_array_index(qrv->qrvs, sw->cur);
                     if (!qi) break;
@@ -752,7 +787,8 @@ sort_text:
 					}
                 case 'u':
                 case 'U':
-           			if (sw->cur < 0 || sw->cur >= qrv->qrvs->len) return 1;
+					if (!aband) break;
+					if (sw->cur < 0 || sw->cur >= qrv->qrvs->len) return 1;
                     qi = (struct qrv_item*)z_ptr_array_index(qrv->qrvs, sw->cur);
                     if (!qi) break;
                     qi->bands_qrv |= 1<<aband->bi;
@@ -782,7 +818,7 @@ char *sw_qrv_call_under(struct subwin *sw, int x, int y0){
     for(i = sw->cur - 1; i >= 0; i--){
         if (y <= 0) break;
         qi = (struct qrv_item *)z_ptr_array_index(qrv->qrvs, i);
-        if (qrv_skip(qi, aband->bi, 0)) continue;
+        if (aband != NULL && qrv_skip(qi, aband->bi, 0)) continue;
 		y--;
 		if (y == y0) return g_strdup(qi->call);
     } 
@@ -791,7 +827,7 @@ char *sw_qrv_call_under(struct subwin *sw, int x, int y0){
     for(i = sw->cur + 1; i < qrv->qrvs->len; i++){
         if (y >= sw->h - 1) break;
         qi = (struct qrv_item *)z_ptr_array_index(qrv->qrvs, i);
-        if (qrv_skip(qi, aband->bi, 0)) continue;
+		if (aband != NULL && qrv_skip(qi, aband->bi, 0)) continue;
 		y++;
 		if (y == y0) return g_strdup(qi->call);
     } 
@@ -887,14 +923,14 @@ int sw_qrv_mouse_func(struct subwin *sw, struct event *ev, int fw){
 			sw->cur--;
 			while (sw->cur >= 0){
 				qi = (struct qrv_item *)z_ptr_array_index(qrv->qrvs, sw->cur);
-				if (!qrv_skip(qi, aband->bi, 0)) break;
+				if (!(aband != NULL && qrv_skip(qi, aband->bi, 0))) break;
 				sw->cur--;
 			}
 		}else{
 			sw->cur++;
 			while (sw->cur < qrv->qrvs->len){
 				qi = (struct qrv_item *)z_ptr_array_index(qrv->qrvs, sw->cur);
-				if (!qrv_skip(qi, aband->bi, 0)) break;
+				if (!(aband != NULL && qrv_skip(qi, aband->bi, 0))) break;
 				sw->cur++;
 			}
 		}
@@ -975,13 +1011,12 @@ int sw_qrv_mouse_func(struct subwin *sw, struct event *ev, int fw){
             break;
         case B_WHUP:
 /*            dbg("wheel up\n");*/
-			if (!aband) return 1;
 			for (i = 0; i < 3; i++){
 				sw->cur--;
 				while (sw->cur >= 0){
 					if (sw->cur >= 0 && sw->cur < qrv->qrvs->len) {
 						qi = (struct qrv_item *)z_ptr_array_index(qrv->qrvs, sw->cur);
-						if (!qrv_skip(qi, aband->bi, 0)) break;
+						if (!(aband != NULL && qrv_skip(qi, aband->bi, 0))) break;
 					}
 					sw->cur--;
 				}
@@ -991,20 +1026,17 @@ int sw_qrv_mouse_func(struct subwin *sw, struct event *ev, int fw){
             return 1;
         case B_WHDOWN:
 /*            dbg("wheel down\n");  */
-			if (!aband) return 1;
 			for (i = 0; i < 3; i++){
 				sw->cur++;
 				while (sw->cur < qrv->qrvs->len){
 					if (sw->cur >= 0 && sw->cur < qrv->qrvs->len) {
 						qi = (struct qrv_item *)z_ptr_array_index(qrv->qrvs, sw->cur);
-						if (!qrv_skip(qi, aband->bi, 0)) break;
+						if (!(aband != NULL && qrv_skip(qi, aband->bi, 0))) break;
 					}
 					sw->cur++;
 				}
 			}
-			dbg("B_WHDOWN: sw->cur=%d ", sw->cur);
             sw->check_bounds(sw);
-			dbg("%d\n", sw->cur);
             redraw_later();
             return 1;
 	}
@@ -1015,13 +1047,13 @@ void sw_qrv_draw_qrv(struct subwin *sw, int i, struct qrv_item *qi, int color){
     gchar *c;
     char degree=' ';
     struct tm utc;
-    char kst_time_str[20];
-    char qrb_str[20];
+    char kst_time_str[200];
+    char qrb_str[400];
     char qtf_str[20];
     char acstart[30];
     char acint[30];
 
-#ifdef Z_HAVE_SDL    
+#if defined(Z_HAVE_SDL) && !defined(Z_ANDROID)     
     //if (sdl) degree='';
     if (sdl) degree=0xb0;
 #endif
@@ -1044,9 +1076,10 @@ void sw_qrv_draw_qrv(struct subwin *sw, int i, struct qrv_item *qi, int color){
 
         ac_format(qi, acstart, acint, 1);
 
+
         c = g_strdup_printf("%-12s  %6s %4d %-7s  "
                             "%-4s  %5s  %s %s %s", 
-                qi->call, qi->wwl, qi->wkd[aband->bi], qrb_str, 
+                qi->call, qi->wwl, aband?qi->wkd[aband->bi]:0, qrb_str, 
                 qtf_str, kst_time_str, acstart, acint, qi->text);
     }
 
@@ -1095,7 +1128,7 @@ void sw_qrv_redraw(struct subwin *sw, struct band *band, int flags){
     int i, y, len, color;
     char *c, raw[30];
 
-    if (!aband) return;
+   // if (!aband) return;
     
     //fill_area(sw->x, sw->y+sw->h/2, sw->w, 1, COL_INV);
     clip_printf(sw, -sw->ho +  2, 0,  qrv->sort==qrv_compare_call?COL_WHITE:COL_NORM, VTEXT(T_CALLSIGN3));
@@ -1133,7 +1166,7 @@ void sw_qrv_redraw(struct subwin *sw, struct band *band, int flags){
 
     qi = (struct qrv_item *)z_ptr_array_index(qrv->qrvs, sw->cur);
 //    dbg("%s: cur=%d qi=%p\n", __FUNCTION__, sw->cur, qi);
-    if (!qi || qrv_skip(qi, aband->bi, 1)) {
+    if (!qi || (aband != NULL && qrv_skip(qi, aband->bi, 1))) {
         print_text(sw->x, sw->y + sw->h/2, sw->w, "~", COL_INV);
         return;
     }
@@ -1148,14 +1181,14 @@ void sw_qrv_redraw(struct subwin *sw, struct band *band, int flags){
     for(i = sw->cur - 1; i >= 0; i--){
         if (y <= 0) break;
         qi = (struct qrv_item *)z_ptr_array_index(qrv->qrvs, i);
-        if (qrv_skip(qi, aband->bi, 1)) continue;
+        if (aband != NULL && qrv_skip(qi, aband->bi, 1)) continue;
 		z_get_raw_call(raw, qi->call);
 		color = sw_qrv_color(raw);
         sw_qrv_draw_qrv(sw, y--, qi, color);
     } 
 	for (; i >= 0; i--){
 		struct qrv_item *qi = (struct qrv_item *)z_ptr_array_index(qrv->qrvs, i);
-		qi->ac_drawn = 0;
+		//qi->ac_drawn = 0;
 		qi->ac_start = (time_t)0;
 	}
 
@@ -1163,14 +1196,14 @@ void sw_qrv_redraw(struct subwin *sw, struct band *band, int flags){
     for(i = sw->cur + 1; i < qrv->qrvs->len; i++){
         if (y >= sw->h - 1) break;
         qi = (struct qrv_item *)z_ptr_array_index(qrv->qrvs, i);
-        if (qrv_skip(qi, aband->bi, 1)) continue;
+		if (aband != NULL && qrv_skip(qi, aband->bi, 1)) continue;
 		z_get_raw_call(raw, qi->call);
 		color = sw_kst_color(raw);
         sw_qrv_draw_qrv(sw, y++, qi, color);
     } 
 	for (; i < qrv->qrvs->len; i++){// ((struct qrv_item *)z_ptr_array_index(qrv->qrvs, i))->ac_drawn = 0;
 		struct qrv_item *qi = (struct qrv_item *)z_ptr_array_index(qrv->qrvs, i);
-		qi->ac_drawn = 0;
+		//qi->ac_drawn = 0;
 		qi->ac_start = (time_t)0;
 	}
 
@@ -1199,7 +1232,7 @@ void sw_qrv_check_bounds(struct subwin *sw){
 
     while (sw->cur < qrv->qrvs->len){
         qi = (struct qrv_item *)z_ptr_array_index(qrv->qrvs, sw->cur);
-        if (!qrv_skip(qi, aband->bi, 1)) break;
+		if (!(aband != NULL && qrv_skip(qi, aband->bi, 1))) break;
         sw->cur++; 
     }
     if (sw->cur >= qrv->qrvs->len) {
@@ -1209,7 +1242,7 @@ void sw_qrv_check_bounds(struct subwin *sw){
              
     while (sw->cur >= 0){
         qi = (struct qrv_item *)z_ptr_array_index(qrv->qrvs, sw->cur);
-        if (!qrv_skip(qi, aband->bi, 0)) break;
+		if (!(aband != NULL && qrv_skip(qi, aband->bi, 0))) break;
         sw->cur--; 
     }
     if (sw->cur < 0) {
@@ -1235,7 +1268,7 @@ void qrv_compute_qrbqtf(struct qrv_item *q){
         return;
     }
     /* CHANGE look at add_tmpqso_locator */    
-    qrbqtf(ctest->pwwlo, q->wwl, &q->qrb, &qtf, NULL, 2);
+    qrbqtf(ctest?ctest->pwwlo:cfg->pwwlo, q->wwl, &q->qrb, &qtf, NULL, 2);
     q->qtf = (int) (qtf+0.5);
     if (q->qrb < 0.1) {
         q->qrb = 0;
@@ -1254,7 +1287,7 @@ void qrv_compute_qrbqtf(struct qrv_item *q){
 
     if (aband){
         if (q->wkd[aband->bi] > 1) q->weight *= q->wkd[aband->bi];
-        if (!(q->bands_qrv && (1 << aband->bi))) q->weight = 0;
+        if (!(q->bands_qrv & (1 << aband->bi))) q->weight = 0;
     }
     /*dbg("compute_qrbqtf(%s) %s->%s qrb=%f kx=%d ky=%d\n", 
             q->call, ctest->pwwlo, q->wwl, q->qrb, q->kx, q->ky); */
