@@ -63,6 +63,7 @@ int init_ctest(){
     ctest->allqsos = z_ptr_array_new();
     ctest->spypeers = g_ptr_array_new();
     ctest->allb_prefs = g_hash_table_new(g_str_hash, g_str_equal);
+    ctest->exclen = 0;
 
 /*    ctest->serial = 1;*/
     ctest->minute_timer_id=zselect_timer_new(zsel, 100, timer_minute_stats_all, NULL);
@@ -144,6 +145,7 @@ int new_ctest(char *tdate){
     }
     g_free(c);
 
+    ctest->exclen = strlen(ctest->pexch);
     fprintf(f,"%s %s %s\n", ctest->cdate, z_str_uc(ctest->pcall), ctest->tname);    
 	fclose(f);
     
@@ -171,6 +173,7 @@ int new_ctest(char *tdate){
 	update_hw();
 #ifdef Z_HAVE_SDL
     maps_reload();
+	maps_update_showwwls();
 #endif  
     
     return 0; 
@@ -1031,6 +1034,7 @@ void add_qso_to_index(struct qso *q, int qsort_if_needed){
         }
     }
     z_ptr_array_add(ctest->allqsos, q);
+    if (strlen(q->exc) > ctest->exclen) ctest->exclen = strlen(q->exc);
 
     qrv_set_wkd(qrv, q);
 }
@@ -1311,6 +1315,7 @@ void free_ctest(){
     }
     
     clear_qrv(qrv);
+	clear_hicalls();
     chart_clear_all();
 
     for (i=0;i<ctest->bands->len; i++){
@@ -1361,8 +1366,8 @@ void free_ctest(){
     
     set_ctest_title();
     cq_abort(1);
-    if (!zselect_terminating(zsel)) 
-	maps_reload();
+    if (!zselect_terminating(zsel))	maps_reload();
+	maps_update_showwwls();
     chart_reload();
 }
 
@@ -1670,6 +1675,18 @@ int worked_on_all_rw(char *call){
     return ret;
 }
 
+int worked_on_aband(char *call){
+    if (!aband) return 0;
+			
+    if (get_qso_by_callsign(aband, call)){
+        return 1;   
+    }
+    else{
+        return 0;
+    }
+}
+
+
 void _dump_rw(gpointer key, gpointer value, gpointer data){
 
 	fprintf((FILE *)data, "key='%s' value=%p ", (char*)key, value);
