@@ -368,6 +368,7 @@ struct contest {
     GHashTable *bystamp;  /* key=source, val=ZPtrArray */
                           /* ZPtrArrays are NOT sorted by ser_id but only by stamp */
     ZPtrArray *allqsos;
+    gint exclen;
     
      /* disk */
     FILE *lockfile;     /* ~/tucnak/.../desc.lock */ 
@@ -463,6 +464,7 @@ int compare_date_time_qsonrs(const void *a, const void *b);
 void set_mode(enum modes mode);
 enum modes get_mode(void);
 int worked_on_all_rw(char *call); // worked on all read-write band
+int worked_on_aband(char *call);
 
 void dump_rw(void *a, void *b);
 int add_qsos_from_swap(struct band *b, FILE *f);
