@@ -130,14 +130,15 @@ enum {
     SYMBOL_CWDA_MAXWPM   = G_TOKEN_LAST + 98,
     SYMBOL_CWDA_SPK      = G_TOKEN_LAST + 99,
     SYMBOL_CWDA_LEADIN   = G_TOKEN_LAST + 100,
-    SYMBOL_CWDA_VID      = G_TOKEN_LAST + 101,
-    SYMBOL_CWDA_PID      = G_TOKEN_LAST + 102,
-    SYMBOL_CWDA_AUTGIVE  = G_TOKEN_LAST + 103,
-    SYMBOL_WK_WK2        = G_TOKEN_LAST + 104,
-    SYMBOL_WK_USEPOT     = G_TOKEN_LAST + 105,
-    SYMBOL_WK_USEBUT     = G_TOKEN_LAST + 106,
-    SYMBOL_WK_KEYMODE    = G_TOKEN_LAST + 107,
-    SYMBOL_WK_SWAP       = G_TOKEN_LAST + 108,
+    SYMBOL_CWDA_TAIL     = G_TOKEN_LAST + 101,
+    SYMBOL_CWDA_VID      = G_TOKEN_LAST + 102,
+    SYMBOL_CWDA_PID      = G_TOKEN_LAST + 103,
+    SYMBOL_CWDA_AUTGIVE  = G_TOKEN_LAST + 104,
+    SYMBOL_WK_WK2        = G_TOKEN_LAST + 105,
+    SYMBOL_WK_USEPOT     = G_TOKEN_LAST + 106,
+    SYMBOL_WK_USEBUT     = G_TOKEN_LAST + 107,
+    SYMBOL_WK_KEYMODE    = G_TOKEN_LAST + 108,
+    SYMBOL_WK_SWAP       = G_TOKEN_LAST + 109,
 
     SYMBOL_SSBD_TYPE       = G_TOKEN_LAST + 110,
     SYMBOL_SSBD_RECORD     = G_TOKEN_LAST + 111,
@@ -250,10 +251,14 @@ enum {
     SYMBOL_KST_USER			 = G_TOKEN_LAST + 234,
 	SYMBOL_KST_PASS			 = G_TOKEN_LAST + 235,
 	SYMBOL_KST_NAME			 = G_TOKEN_LAST + 236,
+	SYMBOL_KST_MINQRB		 = G_TOKEN_LAST + 237,
+	SYMBOL_KST_MAXQRB		 = G_TOKEN_LAST + 238,
+	SYMBOL_SLOVHF_USER		 = G_TOKEN_LAST + 239,
 
     SYMBOL_HTTPD_ENABLE      = G_TOKEN_LAST + 240,
     SYMBOL_HTTPD_PORT        = G_TOKEN_LAST + 241,
     SYMBOL_HTTPD_SHOW_PRIV   = G_TOKEN_LAST + 242,
+    SYMBOL_HTTPD_REFRESH     = G_TOKEN_LAST + 243,
 
     SYMBOL_AC_ENABLE         = G_TOKEN_LAST + 250,
     SYMBOL_AC_URL            = G_TOKEN_LAST + 251,
@@ -295,13 +300,15 @@ enum {
 	SYMBOL_WIKI_CHART        = G_TOKEN_LAST + 295,
 	//SYMBOL_WIKI_OVERWRITE    = G_TOKEN_LAST + 296,
 
-    SYMBOL_RAIN_ENABLE       = G_TOKEN_LAST + 296,
-    SYMBOL_RAIN_METEOX       = G_TOKEN_LAST + 297,
-    SYMBOL_RAIN_WETTERONLINE = G_TOKEN_LAST + 298,
-    SYMBOL_RAIN_CHMI         = G_TOKEN_LAST + 299,
-    SYMBOL_RAIN_DEBUG        = G_TOKEN_LAST + 300,
+    SYMBOL_RAIN_ENABLE        = G_TOKEN_LAST + 296,
+    SYMBOL_RAIN_METEOX        = G_TOKEN_LAST + 297,
+    SYMBOL_RAIN_WETTERONLINE  = G_TOKEN_LAST + 298,
+    SYMBOL_RAIN_CHMI          = G_TOKEN_LAST + 299,
+	SYMBOL_RAIN_WEATHERONLINE = G_TOKEN_LAST + 300,
+	SYMBOL_RAIN_RAINVIEWER    = G_TOKEN_LAST + 301,
+    SYMBOL_RAIN_DEBUG         = G_TOKEN_LAST + 302,
 
-    SYMBOL_MY_LAST           = G_TOKEN_LAST + 302       
+    SYMBOL_MY_LAST            = G_TOKEN_LAST + 303       
 };
 
 void add_symbols(GScanner *scanner){
@@ -406,6 +413,7 @@ void add_symbols(GScanner *scanner){
     g_scanner_add_symbol(scanner,"cwda_maxwpm",    GINT_TO_POINTER(SYMBOL_CWDA_MAXWPM)); 
     g_scanner_add_symbol(scanner,"cwda_spk",       GINT_TO_POINTER(SYMBOL_CWDA_SPK)); 
     g_scanner_add_symbol(scanner,"cwda_leadin",    GINT_TO_POINTER(SYMBOL_CWDA_LEADIN)); 
+    g_scanner_add_symbol(scanner,"cwda_tail",      GINT_TO_POINTER(SYMBOL_CWDA_TAIL)); 
     g_scanner_add_symbol(scanner,"cwda_vid",       GINT_TO_POINTER(SYMBOL_CWDA_VID)); 
     g_scanner_add_symbol(scanner,"cwda_pid",       GINT_TO_POINTER(SYMBOL_CWDA_PID)); 
     g_scanner_add_symbol(scanner,"cwda_autgive",   GINT_TO_POINTER(SYMBOL_CWDA_AUTGIVE)); 
@@ -524,11 +532,15 @@ void add_symbols(GScanner *scanner){
 	g_scanner_add_symbol(scanner,"dxc_pass",       GINT_TO_POINTER(SYMBOL_DXC_PASS));
 	g_scanner_add_symbol(scanner,"kst_user",       GINT_TO_POINTER(SYMBOL_KST_USER));
 	g_scanner_add_symbol(scanner,"kst_pass",       GINT_TO_POINTER(SYMBOL_KST_PASS));
-	g_scanner_add_symbol(scanner,"kst_name",       GINT_TO_POINTER(SYMBOL_KST_NAME));
+	g_scanner_add_symbol(scanner, "kst_name",      GINT_TO_POINTER(SYMBOL_KST_NAME));
+	g_scanner_add_symbol(scanner, "kst_minqrb",    GINT_TO_POINTER(SYMBOL_KST_MINQRB));
+	g_scanner_add_symbol(scanner, "kst_maxqrb",    GINT_TO_POINTER(SYMBOL_KST_MAXQRB));
+	g_scanner_add_symbol(scanner,"slovhf_user",    GINT_TO_POINTER(SYMBOL_SLOVHF_USER));
 	
     g_scanner_add_symbol(scanner,"httpd_enable",     GINT_TO_POINTER(SYMBOL_HTTPD_ENABLE));
     g_scanner_add_symbol(scanner,"httpd_port",       GINT_TO_POINTER(SYMBOL_HTTPD_PORT));
     g_scanner_add_symbol(scanner,"httpd_show_priv",  GINT_TO_POINTER(SYMBOL_HTTPD_SHOW_PRIV));
+    g_scanner_add_symbol(scanner,"httpd_refresh",    GINT_TO_POINTER(SYMBOL_HTTPD_REFRESH));
     
     g_scanner_add_symbol(scanner,"ac_enable",   GINT_TO_POINTER(SYMBOL_AC_ENABLE));
     g_scanner_add_symbol(scanner,"ac_url",      GINT_TO_POINTER(SYMBOL_AC_URL));
@@ -572,6 +584,8 @@ void add_symbols(GScanner *scanner){
     g_scanner_add_symbol(scanner,"rain_meteox",        GINT_TO_POINTER(SYMBOL_RAIN_METEOX));
     g_scanner_add_symbol(scanner,"rain_wetteronline",  GINT_TO_POINTER(SYMBOL_RAIN_WETTERONLINE));
     g_scanner_add_symbol(scanner,"rain_chmi",          GINT_TO_POINTER(SYMBOL_RAIN_CHMI));
+	g_scanner_add_symbol(scanner, "rain_weatheronline", GINT_TO_POINTER(SYMBOL_RAIN_WEATHERONLINE));
+	g_scanner_add_symbol(scanner, "rain_rainviewer",   GINT_TO_POINTER(SYMBOL_RAIN_RAINVIEWER));
     g_scanner_add_symbol(scanner,"rain_debug",         GINT_TO_POINTER(SYMBOL_RAIN_DEBUG));
 
     
@@ -605,6 +619,8 @@ void add_symbols(GScanner *scanner){
 
 gint init_rc(void){
     cfg = g_new0(struct config, 1);
+
+	cfg->kst_maxqrb = 910;
     
     cfg->bands      = g_ptr_array_new();
     cfg->cqs        = g_ptr_array_new();
@@ -625,6 +641,7 @@ gint init_rc(void){
 #endif
 
     cfg->httpd_port = 7380;
+    cfg->httpd_refresh = 300;
 
     cfg->ac_enable = 0;
     cfg->ac_url = g_strdup("");
@@ -695,6 +712,7 @@ gint free_rc(void){
 	FREE_IF_EXISTS(cfg, kst_user);
 	FREE_IF_EXISTS(cfg, kst_pass);
 	FREE_IF_EXISTS(cfg, kst_name);
+	FREE_IF_EXISTS(cfg, slovhf_user);
     
     FREE_IF_EXISTS(cfg,as_floppy_path);
     FREE_IF_EXISTS(cfg,as_mount_cmd);
@@ -1049,6 +1067,7 @@ guint read_one_token(GScanner *scanner){
         STORE_RC_INT      (cfg, SYMBOL_CWDA_MAXWPM,  cwda_maxwpm);
         STORE_RC_INT      (cfg, SYMBOL_CWDA_SPK,     cwda_spk);
         STORE_RC_INT      (cfg, SYMBOL_CWDA_LEADIN,  cwda_leadin);
+        STORE_RC_INT      (cfg, SYMBOL_CWDA_TAIL,    cwda_tail);
         STORE_RC_INT      (cfg, SYMBOL_CWDA_VID,     cwda_vid);
         STORE_RC_INT      (cfg, SYMBOL_CWDA_PID,     cwda_pid);
         STORE_RC_INT      (cfg, SYMBOL_CWDA_AUTGIVE, cwda_autgive);
@@ -1209,10 +1228,13 @@ guint read_one_token(GScanner *scanner){
 		STORE_RC_STRING(cfg, SYMBOL_KST_USER, kst_user);
 		STORE_RC_STRING(cfg, SYMBOL_KST_PASS, kst_pass);
 		STORE_RC_STRING(cfg, SYMBOL_KST_NAME, kst_name);
+		STORE_RC_INT(cfg, SYMBOL_KST_MAXQRB, kst_maxqrb);
+		STORE_RC_STRING(cfg, SYMBOL_SLOVHF_USER, slovhf_user);
 		
         STORE_RC_INT(cfg, SYMBOL_HTTPD_ENABLE, httpd_enable);
         STORE_RC_INT(cfg, SYMBOL_HTTPD_PORT, httpd_port);
         STORE_RC_INT(cfg, SYMBOL_HTTPD_SHOW_PRIV, httpd_show_priv);
+        STORE_RC_INT(cfg, SYMBOL_HTTPD_REFRESH, httpd_refresh);
         
         STORE_RC_INT   (cfg, SYMBOL_AC_ENABLE, ac_enable);
         STORE_RC_STRING(cfg, SYMBOL_AC_URL, ac_url);
@@ -1256,6 +1278,8 @@ guint read_one_token(GScanner *scanner){
         STORE_RC_INT   (cfg, SYMBOL_RAIN_METEOX, rain_meteox);
         STORE_RC_INT   (cfg, SYMBOL_RAIN_WETTERONLINE, rain_wetteronline);
         STORE_RC_INT   (cfg, SYMBOL_RAIN_CHMI, rain_chmi);
+		STORE_RC_INT   (cfg, SYMBOL_RAIN_WEATHERONLINE, rain_weatheronline);
+		STORE_RC_INT   (cfg, SYMBOL_RAIN_RAINVIEWER, rain_rainviewer);
         STORE_RC_INT   (cfg, SYMBOL_RAIN_DEBUG, rain_debug);
 
     }
@@ -1605,6 +1629,7 @@ void save_rc_string(GString *gs){
     g_string_sprintfa(gs, "cwda_maxwpm   = %d\n", cfg->cwda_maxwpm);
     g_string_sprintfa(gs, "cwda_spk      = %d\n", cfg->cwda_spk);
     g_string_sprintfa(gs, "cwda_leadin   = %d\n", cfg->cwda_leadin);
+    g_string_sprintfa(gs, "cwda_tail     = %d\n", cfg->cwda_tail);
     g_string_sprintfa(gs, "cwda_vid      = 0x%04x\n", cfg->cwda_vid);
     g_string_sprintfa(gs, "cwda_pid      = 0x%04x\n", cfg->cwda_pid);
     g_string_sprintfa(gs, "cwda_autgive  = %d\n", cfg->cwda_autgive);
@@ -1728,12 +1753,15 @@ void save_rc_string(GString *gs){
     g_string_sprintfa(gs, "dxc_pass = \"%s\"\n", S(cfg->dxc_pass));
     g_string_sprintfa(gs, "kst_user = \"%s\"\n", S(cfg->kst_user));
     g_string_sprintfa(gs, "kst_pass = \"%s\"\n", S(cfg->kst_pass));
-    g_string_sprintfa(gs, "kst_name = \"%s\"\n", S(cfg->kst_name));
+	g_string_sprintfa(gs, "kst_name = \"%s\"\n", S(cfg->kst_name));
+	g_string_sprintfa(gs, "kst_maxqrb = %d\n", cfg->kst_maxqrb);
+    g_string_sprintfa(gs, "slovhf_user = \"%s\"\n", S(cfg->slovhf_user));
     g_string_sprintfa(gs, "\n");
 
     g_string_sprintfa(gs, "httpd_enable    = %d\n", cfg->httpd_enable);
     g_string_sprintfa(gs, "httpd_port      = %d\n", cfg->httpd_port);
     g_string_sprintfa(gs, "httpd_show_priv = %d\n", cfg->httpd_show_priv);
+    g_string_sprintfa(gs, "httpd_refresh   = %d\n", cfg->httpd_refresh);
     g_string_sprintfa(gs, "\n");
     
     g_string_sprintfa(gs, "ac_enable   = %d\n", cfg->ac_enable);
@@ -1787,6 +1815,8 @@ void save_rc_string(GString *gs){
 	g_string_sprintfa(gs, "rain_meteox = %d\n", cfg->rain_meteox);
 	g_string_sprintfa(gs, "rain_wetteronline = %d\n", cfg->rain_wetteronline);
 	g_string_sprintfa(gs, "rain_chmi = %d\n", cfg->rain_chmi);
+	g_string_sprintfa(gs, "rain_weatheronline = %d\n", cfg->rain_weatheronline);
+	g_string_sprintfa(gs, "rain_rainviewer = %d\n", cfg->rain_rainviewer);
 	g_string_sprintfa(gs, "rain_debug = %d\n", cfg->rain_debug);
     g_string_sprintfa(gs, "\n");
 
