@@ -71,7 +71,7 @@ struct config {   /* depending on callsign */
     gchar *cwda_device, *cwda_hostname;
     gint cwda_udp_port, cwda_io_port;
     gint cwda_speed, cwda_weight, cwda_minwpm, cwda_maxwpm;
-    gint cwda_leadin, cwda_spk;
+    gint cwda_leadin, cwda_tail, cwda_spk;
     gint cwda_vid, cwda_pid, cwda_autgive;
     gint wk_wk2, wk_usepot, wk_usebut, wk_keymode, wk_swap;
     
@@ -117,10 +117,13 @@ struct config {   /* depending on callsign */
 	int dxc_port;
 	char *dxc_user, *dxc_pass;
 	char *kst_user, *kst_pass, *kst_name;
+	int kst_maxqrb;
+	char *slovhf_user;
 
     int httpd_enable;
     int httpd_port;
     int httpd_show_priv;
+    int httpd_refresh;
 
     int ac_enable;       // aircraft is enabled
     char *ac_url;        // URL for fligtradar data
@@ -141,7 +144,7 @@ struct config {   /* depending on callsign */
 	char *wiki_url, *wiki_user, *wiki_pass, *wiki_page;
 	int wiki_map, wiki_chart, wiki_overwrite;
 
-    int rain_enable, rain_meteox, rain_wetteronline, rain_chmi, rain_debug;
+    int rain_enable, rain_meteox, rain_wetteronline, rain_chmi, rain_weatheronline, rain_rainviewer, rain_debug;
 };
 
 
