@@ -1,12 +1,18 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2013-2015 Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2013-2018 Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
     version 2 as published by the Free Software Foundation.
 
 */
+/* TODO
+ I + Q = USB
+ I - Q = LSB
+ SQRT (I * I + Q * Q) = AM
+ FM = atan(Q * I_old-I * Q_old, I * I_old+ Q * Q_old)
+*/
 
 #include "header.h"
 
@@ -51,7 +57,7 @@ struct sdr *gsdr;
 int sw_sdr_kbd_func(struct subwin *sw, struct event *ev, int fw){
 
 	if (!gsdr) return 0;
-    if (!sdl) return 0;
+    //if (!sdl) return 0;
 	switch (ev->x){
 		case 'c':
 		case 'C':
@@ -80,8 +86,8 @@ int sw_sdr_kbd_func(struct subwin *sw, struct event *ev, int fw){
 int sw_sdr_mouse_func(struct subwin *sw, struct event *ev, int fw){
 	int step = 100;
 	if (!gsdr) return 0;
-    if (!sdl) return 0;
-
+    //if (!sdl) return 0;
+#ifdef Z_HAVE_SDL
 	sw->mx = ev->mx - sw->x * FONT_W;
     sw->my = ev->my - sw->y * FONT_H;
 	zchart_mouse(sw->chart, sw->mx, sw->my);
@@ -164,20 +170,22 @@ int sw_sdr_mouse_func(struct subwin *sw, struct event *ev, int fw){
 
 	}
 	sw_sdr_check_bounds(sw);
-
+#endif
 	return 0;
 }
 
 void sw_sdr_check_bounds(struct subwin *sw){
 
-    if (!sdl) return;
+//    if (!sdl) return;
 	if (!gsdr) return;
 	if (!gsdr->filter) return;
 }
 
 
 void sw_sdr_raise(struct subwin *sw){
-    sw->gdirty=1;      
+#ifdef Z_HAVE_SDL    
+    sw->gdirty=1;
+#endif    
 }
 
 
@@ -186,7 +194,7 @@ struct sdr *init_sdr(void){
 	int i, j = 0, r, f;
     struct sdr *sdr;
    
-    dbg("init_sdr  enable=%d  sdl=%p\n", cfg->sdr_enable, sdl);
+    dbg("init_sdr  enable=%d\n", cfg->sdr_enable);
 	if (!cfg->sdr_enable) return NULL;
     //if (!sdl) return NULL;
 
@@ -199,13 +207,16 @@ struct sdr *init_sdr(void){
 	
 	sdr->bfo_phase = 0.0;
 	sdr->load = -1;
+#ifdef Z_HAVE_SDL    
     if (zsdl){
     	sdr->butbg = z_makecol(0, 128, 128);
     }
 
     MUTEX_INIT(sdr->screen);
+#endif
 	MUTEX_INIT(sdr->filter);
 
+#ifdef Z_HAVE_SDL    
     if (sdl){
         for (i = 128; i < 256; i++){
             r = (i-128)*2;
@@ -234,6 +245,7 @@ struct sdr *init_sdr(void){
 		    sdr->grpal[i] = z_makecol(val, val, val);
 	    }
     }
+#endif
 
 	// initial filter, rewritten after source DSP open
 	sdr->samplerate = cfg->sdr_speed ? cfg->sdr_speed : 48000;
@@ -473,7 +485,11 @@ void sdr_ssb(void *xxx){
 	struct subwin *sw = (struct subwin *)xxx;
 	dbg("sdr_ssb\n");
 	cfg->sdr_cw = 0;
-	sw->sdr_ssb->bcolor = gsdr->butbg;
+	sw->
+        sdr_ssb->
+        bcolor = 
+        gsdr->
+        butbg;
 	sw->sdr_cw->bcolor = 0;
 
 	sdr_new_filter(gsdr, gsdr->filter->zero, cfg->sdr_cw_low, cfg->sdr_cw_high, cfg->sdr_ssb_low, cfg->sdr_ssb_high);
@@ -528,6 +544,7 @@ void sdr_lsb(void *xxx){
 }
 
 void sdr_resize(struct sdr *sdr, struct subwin *sw){
+#ifdef Z_HAVE_SDL
     //dbg("sdr_resize\n");
     SDL_Surface *newscr, *oldscr;
 	SDL_Rect r;
@@ -567,7 +584,6 @@ void sdr_resize(struct sdr *sdr, struct subwin *sw){
 
 	buttons_clear(sw->buttons);
 	sw->sdr_by = sw->fft_sp_y + sw->fft_sp_h - 1 + 2;
-
 	sw->sdr_ssb = init_button(sw->screen, 0, sw->sdr_by, sdr_ssb, sw);
 	button_text(sw->sdr_ssb, zsdl->font_h, sdl->gr[14], cfg->sdr_cw ? 0 : sdr->butbg, " SSB ");
 	g_ptr_array_add(sw->buttons, sw->sdr_ssb);
@@ -591,12 +607,14 @@ void sdr_resize(struct sdr *sdr, struct subwin *sw){
 	g_free(sdr->wfvec);
 	sdr->wfvec = g_new0(int, sw->screen->w);
 	sdr->wfveclen = sw->screen->w;
+#endif
 }
 
 
 void sw_sdr_redraw(struct subwin *sw, struct band *band, int flags){
+#ifdef Z_HAVE_SDL    
 	SDL_Rect src, dst, filter_r;
-	int i, y, x = 0, sp_y, oldx, oldy = 0, amp, tw, j;
+	int i, y, x = 0, sp_y, oldx, oldy = 0, amp, tw, j = 1;
 	int bfo_px;//, filter1_px, filter2_px;
 	char s[256];
 	double qrg;
@@ -789,7 +807,7 @@ void sw_sdr_redraw(struct subwin *sw, struct band *band, int flags){
     
     MUTEX_UNLOCK(sw->screen);
     MUTEX_UNLOCK(gsdr->screen);
-
+#endif
 }
 
 
@@ -811,6 +829,12 @@ gpointer sdr_thread_func(gpointer data){
 	zg_thread_set_name("Tucnak SDR");
 	zg_thread_set_priority(2);
 
+#ifdef HAVE_LIBRTLSDR
+#ifdef HAVE_HAMLIB
+	sdr->iqdsp->rtlsdr_frequency = gtrigs->qrg < 24000000 ? 144000000 : gtrigs->qrg;
+#endif
+#endif
+
 	if (sdr->iqdsp->open(sdr->iqdsp, 1) < 0) {
 		zselect_msg_send(zsel, "SDR;!;%s %s", VTEXT(T_CANT_RECORD_FROM_SDR_DSP), sdr->iqdsp->name);
 		return NULL;
@@ -839,7 +863,9 @@ gpointer sdr_thread_func(gpointer data){
 	}
 #endif
 		
+#ifdef Z_HAVE_SDL
 	sdr->screeny = 0;
+#endif
 	sdr->samplerate = sdr->iqdsp->speed;
 	
 	sdr_new_filter(sdr,cfg->sdr_zero, cfg->sdr_cw_low, cfg->sdr_cw_high, cfg->sdr_ssb_low, cfg->sdr_ssb_high);   
@@ -854,12 +880,14 @@ gpointer sdr_thread_func(gpointer data){
 	gettimeofday(&tv1, NULL);
 	oldsec = tv1.tv_sec;
      
+#ifdef Z_HAVE_SDL    
 	MUTEX_LOCK(sdr->screen);
     if (sdr->screen) {
 		for (i = 0; i < sdr->wfveclen; i += 3) z_putpixel(sdr->screen, i, sdr->screeny, sdl->gr[12]);
 		sdr->screeny++;
 	}
 	MUTEX_UNLOCK(sdr->screen);
+#endif
 
 
     while(!sdr->thread_break){
@@ -905,6 +933,7 @@ gpointer sdr_thread_func(gpointer data){
         
 		fftw_execute(sdr->plan_f);
     
+#ifdef Z_HAVE_SDL        
         MUTEX_LOCK(sdr->screen);
         if (sdr->screen){
             oldx = -1;
@@ -967,6 +996,7 @@ gpointer sdr_thread_func(gpointer data){
             if (sdr->screeny == sdr->screen->h) sdr->screeny = 0;
         }
         MUTEX_UNLOCK(sdr->screen);
+#endif        
 
 		MUTEX_LOCK(sdr->filter);
 		for (i = 0; i < sdr->n; i++){
