@@ -24,8 +24,8 @@
 #include "subwin.h"
 #include "subwin.h"
 
-char callsign[EQSO_LEN], locator[EQSO_LEN];
-char time_str[EQSO_LEN], remark[MAX_STR_LEN]; 
+static char callsign[EQSO_LEN], locator[EQSO_LEN];
+static char time_str[EQSO_LEN], remark[MAX_STR_LEN]; 
 
 int sw_sked_kbd_func(struct subwin *sw, struct event *ev, int fw){
 	struct sked *sked;
