@@ -262,7 +262,7 @@ void update_stats(struct band *band, struct stats *st, struct qso *q){
 
     //dbg("update_stats(%s)\n", s);    
 
-    if (g_hash_table_lookup_extended(st->calls, s, &orig_key, (gpointer*) &orig_value)){
+	if (g_hash_table_lookup_extended(st->calls, s, &orig_key, (gpointer*) &orig_value) && ctest->expmode == 0){
         SAD_INT(dupe,1);
     }else{
         g_hash_table_insert(st->calls, g_strdup(s), NULL);
@@ -393,6 +393,9 @@ void update_stats(struct band *band, struct stats *st, struct qso *q){
                     break;
             }
             break;
+		case 20: /* WWL ring Contest Lombardia */
+			qsop = (qsopwr(ctest->pwwlo, q->locator) - 1) * ctest->qsomult * band->qsomultb;
+			break;
 
     }
     if (q->dupe) qsop=0;
@@ -1220,6 +1223,7 @@ void recalc_statsfifo(struct band *b){
         fifo_addf(F, VTEXT(T_SF_ALLBPTS), ctest->allb_ntotal);
     }
     fifo_addf(F, VTEXT(T_SF_QSOS), b->stats->nqsos);  
+    fifo_addf(F, VTEXT(T_SF_VQSO), g_hash_table_size(b->stats->calls));
     fifo_addf(F, VTEXT(T_SF_QSOP), b->stats->nqsop);
     fifo_addf(F, VTEXT(T_SF_PTS), b->stats->ntotal);
     
