@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2016  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2020  Ladislav Vaiz <ok1zia@nagano.cz>
     and authors of web browser Links 0.96
 
     This program is free software; you can redistribute it and/or
@@ -361,12 +361,13 @@ struct subwin *new_subwin(enum sw_type type, int where_){
 
 			sw->adns = zasyncdns_init();
 
-			sw->timer_id = zselect_timer_new(zsel, 1 * 60 * 1000, kst_timer_function, sw);
+			sw->timer_id = 0;
 			sw->kstusers = g_hash_table_new_full(g_str_hash, g_str_equal, g_free, NULL); // 2x
 #ifdef Z_HAVE_SDL
 			sw->zoom = 10000;
 			map_update_qth(sw);
 #endif
+			sw->first_shus = 1;
 
 
 			{
@@ -402,6 +403,7 @@ struct subwin *new_subwin(enum sw_type type, int where_){
 			sw->check_bounds    = sw_sdr_check_bounds;
 			sw->raise           = sw_sdr_raise;
 
+#ifdef Z_HAVE_SDL            
 			if (sdl){
 				sw->buttons = g_ptr_array_new();
 				sw->screen = SDL_CreateRGBSurface(SDL_SWSURFACE, sw->w*FONT_W, sw->h*FONT_H, sdl->bpp, 
@@ -410,6 +412,7 @@ struct subwin *new_subwin(enum sw_type type, int where_){
 				sw->gdirty = 1;
 				sdr_resize(gsdr, sw); 
 			}
+#endif            
 			
 #endif
 
@@ -644,14 +647,13 @@ int sw_printf(struct subwin *sw, const char *m, ...){
 }
 
 int sw_default_func(struct subwin *sw, struct event *ev, int fw){
-    /*dbg("sw_default_func %p,[%d,%d,%d,%d],%d)\n",sw,ev->ev,ev->x,ev->y ,ev->b,fw);*/
-/*    dbg("              term %dx%d \n",term->x, term->y);*/
+    //dbg("sw_default_func %p,[%d,%d,%d,%d],%d)\n",sw,ev->ev,ev->x,ev->y ,ev->b,fw);
+    //dbg("              term %dx%d \n",term->x, term->y);
     switch(ev->ev){
         case EV_ABORT:
 			if (zselect_profiling(zsel)) zselect_hint(zsel, "sw_default_func EV_ABORT %s", sw->title);
-            if (sw->il) 
-                inputln_func(sw->il,ev);
-                sw_shell_kill(sw);
+            if (sw->il) inputln_func(sw->il,ev);
+            sw_shell_kill(sw);
             break;
         case EV_INIT:
 			if (zselect_profiling(zsel)) zselect_hint(zsel, "sw_default_func EV_INIT %s", sw->title);
@@ -993,7 +995,7 @@ void draw_titles(int y, int ontop2){
     }
     if (x-3 < sw->w) goto draw;
 
-/*            if (x+strlen(c)>=sw->w+1) max=sw->w-x+1; else max=-1;
+/*            if (x+strlen(c)>=sw->w+1) max=sw-w-x+1; else max=-1;
             print_text(x,sw->y-1,max,c,col_active);
         }else{    
             c=g_strdup_printf(" %i:%s ", i+1, sw->title);
@@ -1470,7 +1472,7 @@ void sw_qsos_redraw(struct subwin *sw, struct band *band, int flags){
         if (q->unkcall) unkcall=VTEXT(T_HK_NEW_CALL)[0];
         else unkcall=' ';
         sprintf(qtf,"%3d", q->qtf);
-#ifdef Z_HAVE_SDL        
+#if defined(Z_HAVE_SDL) && !defined(Z_ANDROID)     
 //        if (sdl) strcat(qtf, "");
         if (sdl) strcat(qtf, "\xb0");
 #endif
@@ -2506,6 +2508,7 @@ void sw_highlight(struct subwin *sw, const char *text, const char *needle, int c
 }
 
 void sw_set_gdirty(enum sw_type type){
+#ifdef Z_HAVE_SDL    
 	int i;
 	for (i = 0; i < gses->subwins->len; i++){
         struct subwin *sw = (struct subwin *)g_ptr_array_index(gses->subwins, i);
@@ -2513,4 +2516,5 @@ void sw_set_gdirty(enum sw_type type){
         sw->gdirty = 1;
 	}
 	redraw_later();
+#endif    
 }
