@@ -95,7 +95,7 @@ struct subwin {
     int ch_left, ch_right, ch_top, ch_bottom;
     char *ch_op;
     int mx, my, ch_mouse_value;
-	int showlines;
+	int showlines, showwwls;
 #endif    
     double myw, myh;
     GPtrArray *chbands; // of struct chband
@@ -115,7 +115,8 @@ struct subwin {
     int sock;
     int kst_srv;
 	struct zasyncdns *adns;
-	int chat;
+	int chat; // unix chat, not KST chat
+	int first_shus;
 	char *callunder;
 	double qrg; // kHz
 	char *pattern;
