@@ -143,19 +143,25 @@ void trigs_read_handler(struct trigs *trigs, int n, char **items){
     
 	rignr = atoi(items[1]);
     cmd = items[2];
+    dbg("trig_read_handler   nr=%d  cmd='%s'\n", rignr, cmd);
     trig = get_trig_by_number(trigs, rignr);
-    if (!trig){
-        TRTR(0, "#%d: Unknown rig nr", rignr);
-        goto x;
-    }
-//     dbg("trig_read_handler   rcvd: '%s'  cmd='%s'\n", s, cmd);
     if (strcmp(cmd, "!")==0){  /* error */
+		log_addf("Rig %d error: %s", rignr, items[3]);
 		TRTR(0, "#%d: Rig error: %s", rignr, items[3]);
-        g_ptr_array_remove(trigs->trigs, trig);
-        free_trig(trig);
+        if (trig != NULL){
+            g_ptr_array_remove(trigs->trigs, trig);
+            free_trig(trig);
+        }
         progress(NULL);
         goto x;
     }
+    
+    if (!trig){
+       // dbg("Unknown rig nr=%d", rignr);
+        TRTR(0, "#%d: Unknown rig nr", rignr);
+        goto x;
+    }
+
     if (strcasecmp(cmd, "qrg")==0){
 		double freq, lo;
         struct band *b;
@@ -328,10 +334,10 @@ void free_trig(struct trig *trig){
     if (trig->rig){
         rig_close(trig->rig);
         rig_cleanup(trig->rig);
-        if (trig->locked) zfhs_unlock(trig->filename);
         zg_free0(trig->filename);
         trig->rig = NULL;
     }
+    if (trig->locked) zfhs_unlock(trig->filename);
     MUTEX_FREE(trig->jobs);
 	g_free(trig);
 }
@@ -456,7 +462,14 @@ gpointer trig_main(gpointer xxx){
     safe_strncpy(trig->rig->state.rigport.pathname, trig->filename, FILPATHLEN);
     if (trig->speed > 0) trig->rig->state.rigport.parm.serial.rate = trig->speed;
 	if (trig->handshake_none) trig->rig->state.rigport.parm.serial.handshake = RIG_HANDSHAKE_NONE;
-    trig->rig->state.rigport.timeout = 2000;
+
+#ifdef Z_UNIX_ANDROID
+    trig->rig->state.rigport.timeout = 500; // 2000ms rig 311 on Debian 8.10
+#elif defined(Z_MSC_MINGW)
+    trig->rig->state.rigport.timeout = 400;	// 2000ms rig 311 on Windows 7
+#else    
+    trig->rig->state.rigport.timeout = 1000; // probably not reached
+#endif
     civaddr_str = g_strdup_printf("%d", trig->civaddr);
 	rig_set_conf(trig->rig, rig_token_lookup(trig->rig, "civaddr"), civaddr_str);
     g_free(civaddr_str);
@@ -495,8 +508,10 @@ gpointer trig_main(gpointer xxx){
         job = trig_job_get(trig);
         if (!job){
             usleep(trig->poll_ms * 1000);
-            rigerr = rig_get_vfo(trig->rig, &vfo);
-            if (rigerr == -RIG_ENAVAIL){
+			ST_START();
+			rigerr = rig_get_vfo(trig->rig, &vfo);
+			ST_STOP("rig_get_vfo");
+			if (rigerr == -RIG_ENAVAIL){
                 vfo = RIG_VFO_CURR;
             }else{
                 if (rigerr != RIG_OK) {
@@ -506,8 +521,12 @@ gpointer trig_main(gpointer xxx){
                 }
             }
 
+			ST_START();
             usleep(trig->poll_ms * 1000);
-            rigerr = rig_get_freq(trig->rig, vfo, &freq);
+			ST_STOP("poll_ms");
+			ST_START();
+			rigerr = rig_get_freq(trig->rig, vfo, &freq);
+			ST_STOP("rig_get_freq");
             if (rigerr != RIG_OK){
 				TRTR(1, "rig_get_freq(#%d, %s)", trig->nr, rig_strvfo(vfo));
                 gtrigs->rigerr = trig->rigerr = rigerr;
@@ -531,7 +550,7 @@ gpointer trig_main(gpointer xxx){
                 gtrigs->rigerr = trig->rigerr = rigerr;
 				TRTR(1, "rig_get_rit(#%d, %s)", trig->nr, rig_strvfo(vfo));
             } 
-            if (rigerr != -RIG_EINVAL){
+            if (rigerr == RIG_OK){
                 rit = tmprit;
                 if (rit != oldrit){
                     oldrit = rit;
