@@ -48,6 +48,13 @@ SDL_Color pal[256];
 int sdl_test(void);
 #endif
 
+#ifdef Z_MSC_MINGW
+int getaltstate(){
+	SHORT ret = GetKeyState(VK_MENU);// Alt key
+	return (ret & 0x8000) != 0;// high-order bit is 1
+}
+#endif
+
 struct tsdl *init_sdl(){
     int w, h, ty;
     SDL_Rect r;
@@ -398,7 +405,11 @@ int sdl_setvideomode(int w, int h, int init_x){
     }
     for (i=0; i<16; i++){
         int r,g,b;
-        if (i==0x08){
+        /*if (i == 6){ //DARKCYAN KST hack
+            r = 212;
+            g = 212;
+            b = 0; 
+        }else*/ if (i==0x08){
 			r=g=b=96;
 		}else if (i&0x08){
             r=255*(i&0x01);
@@ -772,7 +783,16 @@ int handle_unicode(const SDL_Event *sev, struct event *ev){
 
     /*if (sev->key.keysym.mod & KMOD_SHIFT)           ev->y|=KBD_SHIFT;*/
 	if ((sev->key.keysym.mod & (KMOD_LCTRL|KMOD_RALT)) != (KMOD_LCTRL|KMOD_RALT)){ // skip right alt which switches keyboard layout for accent
+#ifdef Z_MSC_MINGW
+		if (getaltstate()) ev->y|=KBD_ALT;
+		if (sev->key.keysym.mod & (KMOD_ALT|KMOD_META)){
+			if (getaltstate() == 0) {
+				int x = 0;
+			}
+		}
+#else
 		if (sev->key.keysym.mod & (KMOD_ALT|KMOD_META)) ev->y|=KBD_ALT;
+#endif
 		if (sev->key.keysym.mod & KMOD_CTRL)            ev->y|=KBD_CTRL;
 	}
 
@@ -837,6 +857,16 @@ gpointer sdl_event_thread(gpointer handle){
             default: dbg("SDL event type %d\n", sev.type); break;
         }
 #endif
+
+		if (sev.type == SDL_KEYDOWN || sev.type == SDL_KEYUP){
+			//dbg("%s ",  sev.type == SDL_KEYDOWN ? "DOWN" : " UP ");
+			/*switch (sev.key.keysym.sym){
+				case SDLK_LALT: dbg("LALT"); break;
+				case SDLK_TAB: dbg("TAB"); break;
+				case SDLK_a: dbg("a"); break;
+			}*/
+			//dbg("  mod=%x\n", sev.key.keysym.mod);
+		}
         
         switch(sev.type){
             case SDL_KEYDOWN:
@@ -852,14 +882,15 @@ gpointer sdl_event_thread(gpointer handle){
 #if 0
                 //kev=&sev;
     
-                dbg("type=%d state=%d scan=%d sym=%d mod=%d unicode=%d\n", 
-                        sev.key.type, sev.key.state, sev.key.keysym.scancode, sev.key.keysym.sym, sev.key.keysym.mod, sev.key.keysym.unicode);
-                dbg("%d %d\n", SDLK_LCTRL, SDLK_RCTRL);
+                dbg("type=%d state=%d scan=%d sym=%d mod=%d unicode=%d    altstate=0x%x\n",  
+                        sev.key.type, sev.key.state, sev.key.keysym.scancode, sev.key.keysym.sym, sev.key.keysym.mod, sev.key.keysym.unicode,
+						getaltstate());
+                //dbg("%d %d\n", SDLK_LCTRL, SDLK_RCTRL);
 				if (sev.key.keysym.unicode == 43){
 					int aaa = 0;
 				}
 #endif                
-				
+
 				if (sev.key.keysym.sym == SDLK_LCTRL || sev.key.keysym.sym == SDLK_RCTRL) {
                     //dbg("ctrl 111111111111111\n");
                     sdl->ctrl = 1;
@@ -992,9 +1023,21 @@ handle:;
                     ev.x=k;
                 }
 
+#ifdef Z_MSC_MINGW
+				if (getaltstate()) ev.y|=KBD_ALT;
+                if (sev.key.keysym.mod & (KMOD_LALT|KMOD_META)){
+					if (!getaltstate()){
+						int x = 0;
+					}
+				}
+#else
                 if (sev.key.keysym.mod & (KMOD_LALT|KMOD_META)){
                     ev.y|=KBD_ALT;
                 }
+#endif
+
+
+
                     
                 if (sev.key.keysym.mod & KMOD_CTRL){
                     ev.y|=KBD_CTRL;
@@ -1004,6 +1047,7 @@ handle:;
                 if (ev.x) goto sendkeydown;
                 break;
             case SDL_KEYUP:
+
                 if (sev.key.keysym.sym == SDLK_LCTRL || sev.key.keysym.sym == SDLK_RCTRL) {
                     //dbg("ctrl 000000000000000\n");
                     sdl->ctrl = 0;
@@ -1343,6 +1387,7 @@ void progress(char *m, ...){
 	}
     va_start(l, m);
     c = g_strdup_vprintf(m, l);
+    dbg("%s\n", c);
 	tw = strlen(c) + 6;
 	w = tw * zsdl->font_w;
 	w = sdl->progress_w = Z_MAX(w, sdl->progress_w);
