@@ -240,7 +240,7 @@ void vhfcontestnet_contestform(struct zhttp *http){
 	g_free(vcn->status);vcn->status = g_strdup_printf(VTEXT(T_UPLOADING_LOG_FILE_S), z_filename(b->edifile));
 	log_addf(VTEXT(T_UPLOADING_BAND_S), b->bandname);
 
-	log = zfile_readfile(b->edifile);
+	log = zfile_read_textfile(b->edifile);
 	if (log == NULL){
 		g_free(vcn->status);vcn->status = g_strdup_printf(VTEXT(T_CANT_READ_LOG_FILE), b->edifile);
 		zhttp_free(vcn->http); vcn->http = NULL;
